#delimit;
clear;
cap clear;
cap log close;
set mem 500m;
set more off;

*********************************************************

Este programa debe ser utilizado con el Software Stata 
versin 8 o superior. 

Todas las bases de datos del Mdulo de Condiciones
Socioeconmicas pueden ser obtenidas en la pgina de 
Internet del CONEVAL www.coneval.gob.mx o del INEGI, 
www.inegi.gob.mx, y deben estar convertidas a formato 
*.dta. 

En este programa se utilizan las siguientes bases, en formato
Stata, renombrndolas de la siguiente forma:

Base de pobreza multidimensional: pobreza_multidimensional08.dta
Base poblacin: poblacion08.dta

En este programa se utilizan tres tipos de archivos, los cuales 
estn ubicados en las siguientes carpetas:

1) Bases originales: "G:\MedicionMultidimensional\2008\Stata\MCS"
2) Bases generadas: "G:\MedicionMultidimensional\2008\Stata\Bases"
3) Bitcoras: "G:\MedicionMultidimensional\2008\Stata\Log"

Para cambiar estas ubicaciones, se modifican los siguientes
globals; 

gl data="G:\MedicionMultidimensional\2008\Stata\MCS";
gl bases="G:\MedicionMultidimensional\2008\Stata\Bases";
gl log="G:\MedicionMultidimensional\2008\Stata\Log";

log using "$log\PobrezaMultidimensional08.txt", text replace;

*********************************************************
*
*	PROGRAMA PARA LA MEDICIN MULTIDIMENSIONAL
*	DE LA POBREZA 2008
*
*********************************************************

*********************************************************

Parte IX Indicadores de contexto territorial

********************************************************;

**********************************************

Redes sociales;

**********************************************;

*Para la construccin del indicador de redes sociales se utiliza
la informacin proveniente de la base de poblacin, relativa
a la percepcin sobre la facilidad o dificultad de contar con 
apoyo de redes sociales para conseguir trabajo, ayuda para cuidar 
a los hijos/hijas, conseguir dinero, apoyo en caso de enfermedad, 
compaa para ir al doctor y cooperacin para mejoras de la colonia 
o localidad;

*Factores de expansin;

use "$data\concentrado08.dta", clear;

keep proyecto folioviv foliohog factor;

label var factor "Factor de expansin";

sort proyecto folioviv foliohog factor;

save "$bases\factores08.dta", replace;

*******************************
*ndice de percepcin de redes*
*******************************;

use "$data\poblacion08.dta", clear;

sort proyecto folioviv foliohog;

merge proyecto folioviv foliohog using "$bases\factores08.dta";

tab _merge;
drop _merge;

*Poblacin objeto;

drop if parentesco>=400 & parentesco <500;
drop if parentesco>=700 & parentesco <800;

*Identificacin de los hogares con poblacin menor a 12 aos;

gen men12=1 if edad>=0 & edad<12;
egen menh12=sum(men12), by(proyecto folioviv foliohog);
replace menh12=1 if menh12>=1 & menh12!=.;

label var menh12 "Indicadora de existencia de poblacin menor 
de 12 aos de edad";
label define menh12 0 "No hay menores de 12 aos en el hogar" 
1 "Hay menores de 12 aos en el hogar";
label value menh12 menh12;

*Esta seccin se pregunta slo a personas de 12 aos y ms,
se elimina a la poblacin no considerada;

drop if edad<12;

recode  redsoc_* (-1=.);

*Se eliminan de la base las observaciones correspondientes a informantes indirectos;

drop if  redsoc_1==. &  redsoc_2==. &  redsoc_3==. &  
redsoc_4==. &  redsoc_5==. &  redsoc_6==.;

*Indicadoras de facilidad de contar con redes;

gen pfr_dinero=1 if redsoc_1==3 | redsoc_1==4;
recode pfr_dinero (.=0) if redsoc_1!=.;

gen pfr_cuiden=1 if redsoc_2==3 | redsoc_2==4;
recode pfr_cuiden (.=0) if redsoc_2!=.;

gen pfr_trabajo=1 if redsoc_3==3 | redsoc_3==4;
recode pfr_trabajo (.=0) if redsoc_3!=.;

gen pfr_acomp=1 if redsoc_4==3 | redsoc_4==4;
recode pfr_acomp (.=0) if redsoc_4!=.;

gen pfr_mejoras=1 if redsoc_5==3 | redsoc_5==4;
recode pfr_mejoras (.=0) if redsoc_5!=.;

gen pfr_cmenores=1 if redsoc_6==3 | redsoc_6==4 & menh12==1;
recode pfr_cmenores (.=0) if redsoc_6!=. & menh12==1;

*Nmero de situaciones en las que se percibe facilidad de
contar con apoyo de redes sociales;

gen nsf=pfr_cuiden+pfr_dinero+pfr_trabajo+pfr_acomp+pfr_mejoras+pfr_cmenores if menh12==1;
replace nsf=pfr_cuiden+pfr_dinero+pfr_trabajo+pfr_acomp+pfr_mejoras if menh12==0;

*Indicadoras de dificultad para contar con redes;

gen pdr_dinero=1 if redsoc_1==1 | redsoc_1==2;
recode pdr_dinero (.=0) if redsoc_1!=.;

gen pdr_cuiden=1 if redsoc_2==1 | redsoc_2==2;
recode pdr_cuiden (.=0) if redsoc_2!=.;

gen pdr_trabajo=1 if redsoc_3==1 | redsoc_3==2;
recode pdr_trabajo (.=0) if redsoc_3!=.;

gen pdr_acomp=1 if redsoc_4==1 | redsoc_4==2;
recode pdr_acomp (.=0) if redsoc_4!=.;

gen pdr_mejoras=1 if redsoc_5==1 | redsoc_5==2;
recode pdr_mejoras (.=0) if redsoc_5!=.;

gen pdr_cmenores=1 if (redsoc_6==1 | redsoc_6==2) & menh12==1;
recode pdr_cmenores (.=0) if redsoc_6!=. & menh12==1;

*Nmero de situaciones en las que se percibe dificultad de
contar con apoyo de redes sociales;

gen nsd=pdr_cuiden+pdr_dinero+pdr_trabajo+pdr_acomp+pdr_mejoras+pdr_cmenores if menh12==1;
replace nsd=pdr_cuiden+pdr_dinero+pdr_trabajo+pdr_acomp+pdr_mejoras if menh12==0;

*Indicadoras de no tener facilidad ni dificultad de contar con apoyo de
redes sociales;

gen pnr_dinero=1 if redsoc_1==5;
recode pnr_dinero (.=0) if redsoc_1!=.;

gen pnr_cuiden=1 if redsoc_2==5;
recode pnr_cuiden (.=0) if redsoc_2!=.;

gen pnr_trabajo=1 if redsoc_3==5;
recode pnr_trabajo (.=0) if redsoc_3!=.;

gen pnr_acomp=1 if redsoc_4==5;
recode pnr_acomp (.=0) if redsoc_4!=.;

gen pnr_mejoras=1 if redsoc_5==5;
recode pnr_mejoras (.=0) if redsoc_5!=.;

gen pnr_cmenores=1 if redsoc_6==5 & menh12==1;
recode pnr_cmenores (.=0) if redsoc_6!=. & menh12==1;

*Nmero de situaciones en las que no se percibe facilidad ni dificultad de
contar con apoyo de redes sociales;

gen nsn=pnr_cuiden+pnr_dinero+pnr_trabajo+pnr_acomp+pnr_mejoras+pnr_cmenores if menh12==1;
replace nsn=pnr_cuiden+pnr_dinero+pnr_trabajo+pnr_acomp+pnr_mejoras if menh12==0;

*Grado percibido de apoyo de redes sociales;

gen ga_redes=.;
replace ga_redes=1 if (nsd>nsf) & (nsd>nsn);
replace ga_redes=2 if (nsn>nsd) & (nsn>nsf);
replace ga_redes=2 if (nsn==nsf) & (nsn>nsd);
replace ga_redes=2 if (nsn==nsd) & (nsn>nsf);
replace ga_redes=2 if (nsn==nsd) & (nsn==nsf);
replace ga_redes=2 if (nsf==nsd) & (nsf>nsn);
replace ga_redes=3 if (nsf>nsd) & (nsf>nsn);

label var ga_redes "Grado de apoyo de contar con redes sociales";
label define ga_redes 1 "Bajo" 2 "Medio" 3 "Alto";
label value ga_redes ga_redes;

tab ga_redes, gen(ga_redes);

*Informacin a nivel estatal;

*Entidad;

gen ent=real(substr(folioviv,1,2));

gen tot_respr=1;

collapse (sum) tot_resp ga_redes1 ga_redes2 ga_redes3 [fw=factor], by(ent);

label var ga_redes1 "Poblacin que percibe un grado de apoyo bajo para contar con redes";
label var ga_redes2 "Poblacin que percibe un grado de apoyo medio para contar con redes";
label var ga_redes3 "Poblacin que percibe un grado de apoyo alto para contar con redes";

label var tot_respr "Total de la poblacin que respondi la seccin de redes sociales";

gen prop_bajo=ga_redes1/tot_respr;
gen prop_medio=ga_redes2/tot_respr;
gen prop_alto=ga_redes3/tot_respr;

label var prop_bajo "Proporcin con un grado de apoyo bajo para contar con redes";
label var prop_medio "Proporcin con un grado de apoyo medio para contar con redes";
label var prop_alto "Proporcin con un grado de apoyo alto para contar con redes";

*ndice estatal;

gen ipest_redes=1 if prop_alto<0.2;
replace ipest_redes=2 if prop_alto>=0.2 & prop_alto<0.4;
replace ipest_redes=3 if prop_alto>=0.4;

label var ipest_redes "ndice estatal de percepcin de redes sociales";
label define ipest_redes 1 "Bajo" 2 "Medio" 3 "Alto";
label value ipest_redes ipest_redes;

sort ent;

save "$bases\redes08.dta", replace;

*********************************************

Desigualdad del ingreso;

*********************************************;

*Para la construccin de los indicadores de desigualdad del ingreso 
se emplea la base pobreza_multidimensional08, de la cual se retoma 
el ingreso corriente total per cpita para la construccin del 
ndice de Gini a nivel estatal;

use "$bases\pobreza_multidimensional08.dta", clear;

*La ejecucin de los siguientes comandos requiere disponer de
conexin a internet;

net stb 23 sg30;

net install sg30.pkg;

inequal ictpc [fw=factor] if p_multi!=.;

scalar gini_nac=0.5055;

foreach x in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 
21 22 23 24 25 26 27 28 29 30 31 32 {;
inequal ictpc [fw=factor] if p_multi!=. & ent==`x';
};

gen 		gini_est	=	0.5087	 if ent==	1	;
replace 	gini_est	=	0.4509	 if ent==	2	;
replace 	gini_est	=	0.4878	 if ent==	3	;
replace 	gini_est	=	0.5231	 if ent==	4	;
replace 	gini_est	=	0.4718	 if ent==	5	;
replace 	gini_est	=	0.4501	 if ent==	6	;
replace 	gini_est	=	0.5565	 if ent==	7	;
replace 	gini_est	=	0.5306	 if ent==	8	;
replace 	gini_est	=	0.5105	 if ent==	9	;
replace 	gini_est	=	0.4955	 if ent==	10	;
replace 	gini_est	=	0.4434	 if ent==	11	;
replace 	gini_est	=	0.5392	 if ent==	12	;
replace 	gini_est	=	0.4909	 if ent==	13	;
replace 	gini_est	=	0.4652	 if ent==	14	;
replace 	gini_est	=	0.4263	 if ent==	15	;
replace 	gini_est	=	0.4821	 if ent==	16	;
replace 	gini_est	=	0.4778	 if ent==	17	;
replace 	gini_est	=	0.4777	 if ent==	18	;
replace 	gini_est	=	0.4900	 if ent==	19	;
replace 	gini_est	=	0.5083	 if ent==	20	;
replace 	gini_est	=	0.4762	 if ent==	21	;
replace 	gini_est	=	0.5036	 if ent==	22	;
replace 	gini_est	=	0.5016	 if ent==	23	;
replace 	gini_est	=	0.5031	 if ent==	24	;
replace 	gini_est	=	0.4847	 if ent==	25	;
replace 	gini_est	=	0.4713	 if ent==	26	;
replace 	gini_est	=	0.5255	 if ent==	27	;
replace 	gini_est	=	0.4829	 if ent==	28	;
replace 	gini_est	=	0.4247	 if ent==	29	;
replace 	gini_est	=	0.4950	 if ent==	30	;
replace 	gini_est	=	0.4870	 if ent==	31	;
replace 	gini_est	=	0.5103	 if ent==	32	;


**********************************************

Razn de ingreso;

**********************************************;

*Para la construccin de este indicador de obtiene el total
de ingresos que concentra la poblacin pobre multidimensional
extrema y la poblacin no pobre multidimensional y no vulnerable.
Se reporta el cociente entre estas dos cantidades;

*Nacional;

summ ictpc [fw=factor] if pe_multi==1;
scalar tin_pem=r(sum);

summ ictpc [fw=factor] if pnpmnv==1;
scalar tin_npmnv=r(sum);

scalar rin_pme_npmnv=tin_pem/tin_npmnv;

*Estatal;

gen ictpc_pem=ictpc*pe_multi;
gen ictpc_npmnv=ictpc*pnpmnv;

gen pob_tot=1 if p_multi!=.;

collapse (sum) ictpc_pem ictpc_npmnv pob_tot (mean) gini_est [fw=factor], by(ent);

gen rie_pme_npmnv=ictpc_pem/ictpc_npmnv;

**********************************************

Polarizacin social;

**********************************************;

*Para la construccin del grado de polarizacin social se usa
la informacin sobre el ndice de marginacin de CONAPO a nivel 
municipal. Se clasifica a las entidades de acuerdo a cuatro categoras:

1. Entidades polarizadas:

Concentran menos de 20 por ciento de la poblacin en municipios 
con grado de marginacin medio, al menos 30 por ciento en municipios 
de grado de marginacin alto y muy alto, y al menos 30 por ciento
en municipios con grado de marginacin bajo o muy bajo.

2. Entidades con polo de alta marginacin:

Concentran ms de 70 por ciento de su poblacin en municipios 
con grado de marginacin alto o muy alto.

3. Entidades con polo de baja marginacin:

Concentran ms de 70 por ciento de su poblacin en municipios 
con grado de marginacin bajo o muy bajo.

4. Entidades sin polo:

Se excluye a las entidades polarizadas, con polo de alta marginacin
o con polo de baja marginacin

De acuerdo a esta clasificacin se define para cada entidad su grado de
polarizacin;

gen polarizacion=.;
replace polarizacion=1 if 	ent==12 | ent==13 | ent==24 | ent==31;
replace polarizacion=2 if 	ent==7;
replace polarizacion=3 if 	ent==1 | ent==2 | ent==3 | ent==5 |
						ent==6 | ent==8 | ent==9 | ent==10 |
						ent==14 | ent==15 | ent==17 | ent==18 |
						ent==19 | ent==22 | ent==23 | ent==25 |
						ent==26 | ent==28 | ent==29 | ent==32;
replace polarizacion=4 if 	ent==4 | ent==11 | ent==16 | ent==20 |
						ent==21 | ent==27 | ent==30;

label var pob_tot "Poblacin total";
label var gini_est "Coeficiente de Gini a nivel estatal";
label var ictpc_pem "Total de ingreso que concentra la poblacin 
pobre multidimensional extrema";
label var ictpc_npmnv "Total de ingreso que concentra la poblacin 
no pobre multidimensional y no vulnerable";
label var rie_pme_npmnv "Razn de ingreso entre la poblacin pobre 
multidimensional y la no pobre multidimensional y no vulnerable";

label var polarizacion "Grado de polarizacin social";
label define polarizacion 	1 "Polarizados" 2 "Polo de alta marginacin" 
						3 "polo de baja marginacin" 4 "Sin polo";

label value polarizacion polarizacion;

sort ent;

merge ent using "$bases\redes08.dta";

tab _merge;
drop _merge;

order  ent gini_est rie_pme_npmnv polarizacion ipest_redes;

sort ent;

save "$bases\contexto08.dta", replace;

**************************
*Concentrado de tabulados*
**************************

******
*Gini*
******;

*Nacional;

di gini_nac;

*Estatal

*Para ver la informacin quitar el asterisco al siguiente comando:

*br ent gini;

******************
*Razn de ingreso*
******************;

di rin_pme_npmnv;

*Estatal

*Para ver la informacin quitar el asterisco al siguiente comando:

*br ent  rie_pme_npmnv;

**************
*Polarizacin*
**************;

tab polarizacion [fw=pob_tot];

****************
*Redes sociales*
****************;

tab  ipest_redes [fw=pob_tot];

log close;







