#delimit;
clear;
cap clear;
cap log close;
set mem 500m;
set more off;

*********************************************************

Este programa debe ser utilizado con el Software Stata 
versin 8 o superior. 

Todas las bases de datos del Mdulo de Condiciones
Socioeconmicas pueden ser obtenidas en la pgina de 
Internet del CONEVAL www.coneval.gob.mx o del INEGI, 
www.inegi.org.mx, y deben estar convertidas a formato 
*.dta. 

En este programa se utilizan las siguientes bases, en formato
Stata, renombrndolas de la siguiente forma:

Base hogares: hogares08.dta
Base poblacin: poblacion08.dta
Base de trabajos: trabajos08.dta
Base de ingresos: ingresos08.dta
Base de concentrado: concentrado08.dta
Bases de no monetario: nomonetarioe08.dta, nomonetariom08.dta

En este programa se utilizan tres tipos de archivos, los cuales 
estn ubicados en las siguientes carpetas:

1) Bases originales: "G:\MedicionMultidimensional\2008\Stata\MCS"
2) Bases generadas: "G:\MedicionMultidimensional\2008\Stata\Bases"
3) Bitcoras: "G:\MedicionMultidimensional\2008\Stata\Log"

Para cambiar estas ubicaciones, se modifican los siguientes
globals; 

gl data="D:\MedicionMultidimensional\2008\Stata\MCS";
gl bases="D:\MedicionMultidimensional\2008\Stata\Bases";
gl log="D:\MedicionMultidimensional\2008\Stata\Log";

log using "$log\PobrezaMultidimensional08.txt", text replace;

*********************************************************
*
*	PROGRAMA PARA LA MEDICIN MULTIDIMENSIONAL
*	DE LA POBREZA 2008
*
*********************************************************

De acuerdo a la metodologa para la medicin multidimensional
de la pobreza establecida por el CONEVAL, la medicin de la 
pobreza se realiza en tres espacios: el espacio del bienestar 
econmico (ingreso), el espacio de derechos sociales (privacin
social) y el contexto territorial (cohesin social).

En este programa se construyen bases independientes para cada
una de las dimensiones a considerar (rezago educativo, acceso a 
la salud, calidad y espacios de la vivienda, servicios bsicos en la 
vivienda, acceso a la seguridad social, acceso a la alimentacin e 
ingreso), y al final se integran en un solo archivo
para efectuar la medicin.


*********************************************************

Parte I Indicadores de Privacin Social:

INDICADOR DE CARENCIA POR REZAGO EDUCATIVO

*********************************************************;

use "$data\poblacion08.dta", clear;

*Poblacin objeto: no se incluye a huspedes ni trabajadores domsticos;

drop if parentesco>=400 & parentesco <500;
drop if parentesco>=700 & parentesco <800;

*Para la construccin del indicador de carencia por rezago
educativo, se utilizan las variables de edad, ao de nacimiento,
asistencia a la escuela y nivel educativo.

*Definicin de variables;

*EDAD;

label var edad "Edad reportada al momento de la entrevista";

*AO DE NACIMIENTO;

gen anio_med=2008;

gen anac_e=.;
replace anac_e=anio_med-edad if edad!=.;

label var anac_e "Ao de nacimiento";

*INASISTENCIA A LA ESCUELA (se reporta para personas de 3 aos o ms);

gen inas_esc=.;
replace inas_esc=0 if asis_esc==1;
replace inas_esc=1 if asis_esc==2;

label var inas_esc "Inasistencia a la escuela";
label define inas_esc  0 "S asiste" 
                       1 "No asiste";
label value inas_esc inas_esc;

*NIVEL EDUCATIVO (se reporta para personas de 3 aos y ms)

/***********************************************************************

La variable de nivel educativo contiene tres categoras:

1. Poblacin que no asisti a la escuela, o cuyo mximo nivel de estudios 
es preescolar o 5o. grado de primaria.

2. Poblacin cuyo mximo nivel educativo es 6o. grado de primaria, 1er. o 2o.
grado de secundaria; 1er. o 2o. grado de carrera tcnica o comercial con 
antecedente de primaria; o, 1er. o 2o. grado de normal con antecedente de primaria.

3. Poblacin cuyo mximo nivel de estudios es 3er. grado de secundaria, 
3er. grado de carrera tcnica o comercial con antecedente primaria, carrera 
tcnica o comercial con antecedente de secundaria o preparatoria, 3er. grado 
de normal con antecedente de primaria, normal con antecedente de 
secundaria o preparatoria, preparatoria o bachillerato; profesional, maestra
o doctorado. 

**********************************************************************/;

gen niv_ed=.;

replace niv_ed = 0 if (n_instr161<2) | (n_instr161==2 & n_instr162<6);

replace niv_ed = 1 if  (n_instr161==2 & n_instr162==6) | 
     (n_instr161==3 & n_instr162<3) | 
     (n_instr161==5 | n_instr161==6) & n_instr162<3 & antec_esc==1;
    

replace niv_ed = 2 if (n_instr161==3 & n_instr162==3) | 
     (n_instr161==4) | 
     (n_instr161==5 & antec_esc==1 & n_instr162>=3) |
     (n_instr161==6 & antec_esc==1 & n_instr162>=3) | 
     (n_instr161==5 & antec_esc>=2 & antec_esc!=.) | 
     (n_instr161==6 & antec_esc>=2 & antec_esc!=.) | 
     (n_instr161>=7 & n_instr161!=.);

label var niv_ed "Nivel educativo";
label define niv_ed  0 "Con primaria incompleta o menos" 
                     1 "Primaria completa o secundaria incompleta"
                     2 "Secundaria completa o mayor nivel educativo";
label value niv_ed niv_ed;

*Existen 98 casos que tienen normal o tcnica pero sin antecedente, por tanto no se puede
saber nada de ellos y se toman como missing values;

***********************************************************************
*
* INDICADOR DE CARENCIA POR REZAGO EDUCATIVO
*
***********************************************************************

Se considera en situacin de carencia por rezago educativo 
a la poblacin que cumpla con alguno de los siguientes criterios:

1. Se encuentra entre los 3 y los 15 aos y no ha terminado la educacin 
obligatoria (secundaria terminada) o no asiste a la escuela.
2. Tiene una edad de 16 aos o ms, su ao de nacimiento aproximado es 1981 
o anterior, y no dispone de primaria completa.
3. Tiene una edad de 16 aos o ms, su ao de nacimiento aproximado es 1982 
en adelante, y no dispone de primaria secundaria completa.

No se considera en situacin de carencia por rezago educativo 
a la poblacin que cumpla con alguno de los siguientes criterios:

1. Tiene una edad menor a la requerida para estar inscrito en el
sistema educativo nacional.
2. Se encuentra entre los 3 y 15 aos y asiste a un centro de 
educacin formal.
3. Se encuentra entre los 3 y 15 aos y dispone de la educacin obligatoria 
(secundaria terminada). 
4. Tiene una edad de 16 aos o ms, su ao de nacimiento aproximado es 1981 
o anterior, y dispone de educacin primaria completa o un mayor nivel educativo.
5. Tiene una edad de 16 aos o ms, su ao de nacimiento aproximado es 1982 
en adelante, y dispone de educacin secundaria completa o un mayor nivel educativo.

***********************************************************************;

gen ic_rezedu=.;

replace ic_rezedu=1 if  (edad>=3 & edad<=15) & inas_esc==1 & (niv_ed==0 | niv_ed==1);
replace ic_rezedu=1 if  (edad>=16 & edad!=.) & (anac_e>=1982 & anac_e!=.) 
          & (niv_ed==0 | niv_ed==1);
replace ic_rezedu=1 if  (edad>=16 & edad!=.) & (anac_e<=1981) & (niv_ed==0);
replace ic_rezedu=0 if  (edad>=0 & edad<=2);
replace ic_rezedu=0 if  (edad>=3 & edad<=15) & inas_esc==0;
replace ic_rezedu=0 if  (edad>=3 & edad<=15) & inas_esc==1 & (niv_ed==2);
replace ic_rezedu=0 if  (edad>=16 & edad!=.) & (anac_e>=1982 & anac_e!=.) 
          & (niv_ed==2);
replace ic_rezedu=0 if  (edad>=16 & edad!=.) & (anac_e<=1981) & (niv_ed==1 | niv_ed==2);


label var ic_rezedu "Indicador de carencia por rezago educativo";

label define ic_rezedu 0 "No presenta carencia"
                                1 "Presenta carencia";
label value ic_rezedu ic_rezedu;

keep proyecto folioviv foliohog numren edad anac_e inas_esc niv_ed ic_rezedu;

sort proyecto folioviv foliohog numren;

save "$bases\ic_rezedu08.dta", replace;


*********************************************************

Parte II Indicadores de Privacin Social:

INDICADOR DE CARENCIA POR ACCESO A LOS SERVICIOS DE SALUD

*********************************************************;

use "$data\poblacion08.dta", clear;

*Poblacin objeto: no se incluye a huspedes ni trabajadores domsticos;


drop if parentesco>=400 & parentesco <500;
drop if parentesco>=700 & parentesco <800;

*Para la construccin del indicador de carencia por acceso 
a los servicios de salud se utilizan las variables de afiliacin o
inscripcin al seguro popular, afiliacin o inscripcin a una 
institucin de salud.

*Definicin de variables;

*SERVICIOS DE SALUD

Se identifica si la poblacin cuenta con Seguro Popular,
servicios mdicos del IMSS, ISSSTE o ISSSTE estatal, PEMEX, 
Defensa o Marina u otros servicios mdicos;

gen serv_sal=.;
replace serv_sal=1 if segpop==1;
replace serv_sal=2 if segpop==2 & atemed==1 & inst_1==1;
replace serv_sal=3 if segpop==2 & atemed==1 & inst_2==2;
replace serv_sal=3 if segpop==2 & atemed==1 & inst_3==3;
replace serv_sal=4 if segpop==2 & atemed==1 & inst_4==4;
replace serv_sal=5 if segpop==2 & atemed==1 & inst_5==5;
replace serv_sal=0 if segpop==2 & atemed==2;

label var serv_sal "Servicios de salud";
label define serv_sal         0 "No cuenta con servicios mdicos" 
                              1 "Seguro Popular" 
                              2 "IMSS" 
                              3 "ISSSTE o ISSSTE estatal" 
                              4 "Pemex, Defensa o Marina" 
                              5 "Otros"; 
label value serv_sal serv_sal;

***********************************************************************
*
* INDICADOR DE CARENCIA POR ACCESO A LOS SERVICIOS DE SALUD
*
***********************************************************************

Se considera en situacin de carencia por acceso a servicios de salud
a la poblacin que:

1. No se encuentra afiliada o inscrita al Seguro Popular o alguna 
institucin que proporcione servicios mdicos.

No se considera en situacin de carencia por acceso a los servicios de salud
a la poblacin que:

1. Se encuentra afiliada o inscrita al Seguro Popular o alguna
institucin que proporcione servicios mdicos.

***********************************************************************;

gen ic_asalud=.;
replace ic_asalud=1 if serv_sal==0;
replace ic_asalud=0 if serv_sal==1 | serv_sal==2 | serv_sal==3 | serv_sal==4 | serv_sal==5;

label var ic_asalud "Indicador de carencia por acceso a servicios de salud";

label define ic_asalud  0 "No presenta carencia"
                        1 "Presenta carencia";
label value ic_asalud ic_asalud;

keep proyecto folioviv foliohog numren sexo edo_salud serv_sal ic_asalud;

sort proyecto folioviv foliohog numren;

save "$bases\ic_asalud08.dta", replace;

*********************************************************

Parte III Indicadores de Privacin social:

INDICADOR DE CARENCIA POR ACCESO A LA SEGURIDAD SOCIAL

*********************************************************;

*Para la construccin del indicador de esta dimensin se 
requiere de informacin relativa a: condicin laboral, 
prestaciones laborales, parentesco, edad, asistencia a la escuela,
ingresos provenientes de pensiones, entre otras.

*En primer lugar se identifica a la poblacin ocupada y sus
prestaciones, tanto en el trabajo principal como el secundario.

*En segundo lugar se analiza los ingresos provenientes
por jubilaciones y pensiones, o por programas de adultos 
mayores.

*En tercer lugar se une la informacin de las dos bases
previas a la base de poblacin para la construccin del 
indicador;


************************
*Prestaciones laborales*
************************;

use "$data\trabajos08.dta", clear;


*TIPO DE TRABAJADOR: identifica la poblacin subordinada e independiente;

*Subordinados;

gen tipo_trab=.;
replace tipo_trab=1 if subor==1;

*Independientes que reciben un pago;

replace tipo_trab=2 if subor==2 & indep==1 & tiene_suel==1;
replace tipo_trab=2 if subor==2 & indep==2 & pago==1;

*Independientes que no reciben un pago;

replace tipo_trab=3 if subor==2 & indep==1 & tiene_suel==2;
replace tipo_trab=3 if subor==2 & indep==2 & (pago==2 | pago==3);


*PRESTACIONES BSICAS POR PARTE DEL TRABAJADOR

Prestaciones laborales: incapacidad en caso de enfermedad o 
maternidad con goce de sueldo y SAR o Afore);

gen inclab=0 if pres_1==.;
replace inclab=1 if pres_1==1;


gen aforlab=0 if pres_8==.;
replace aforlab=1 if pres_8==8;


*OCUPACIN PRINCIPAL Y SECUNDARIA.
Distincin de prestaciones en trabajo principal y secundario;
 
recode numtrab (1=1)(2=0), gen (ocupa);

*Distincin de prestaciones en trabajo principal y secundario;

keep proyecto folioviv foliohog numren numtrab tipo_trab inclab aforlab ocupa;

reshape wide tipo_trab inclab aforlab ocupa, i(proyecto folioviv foliohog numren) j( numtrab);

label var tipo_trab1 "Tipo de trabajo 1";
label var tipo_trab2 "Tipo de trabajo 2";

label var inclab1 "Incapacidad con goce de sueldo en ocupacin principal";
label define inclab 0 "No cuenta" 
                    1 "S cuenta";
label value inclab1 inclab;

label var inclab2 "Incapacidad con goce de sueldo en ocupacin secundaria";
label value inclab2 inclab;

label var aforlab1 "Ocupacin principal: SAR o Afore";
label define aforlab 0 "No cuenta" 
                     1 "S cuenta";
label value aforlab1 aforlab;

label var aforlab2 "Ocupacin secundaria: SAR o Afore";
label value aforlab2 aforlab;

label var ocupa1 "Ocupacin principal";

recode ocupa2 (0=1)(.=0);
label var ocupa2 "Ocupacin secundaria";
label define ocupa   0 "Sin ocupacin secundaria" 
                     1 "Con ocupacin secundaria";

label value ocupa2 ocupa;


*Identificacin de la poblacin trabajadora (toda la que reporta
al menos un empleo en la base de trabajos08.dta);

gen trab=1;

label var trab "Poblacin con al menos un empleo";

keep proyecto folioviv foliohog numren trab tipo_trab* inclab* aforlab* ocupa*;

sort proyecto folioviv foliohog numren;

save "$bases\prestaciones08.dta", replace;


************************
*Ingresos por pensiones*
************************;

use "$data\ingresos08.dta", clear;

*Se identifica a la poblacin que:

- Recibe ingresos por jubilaciones y/o pensiones originadas 
dentro o fuera del pas.

- Recibe ingresos por programas para adultos mayores;

keep if clave=="P032" | clave=="P033" | clave=="P044";

*Para definir el ingreso mensual promedio por programas de adultos 
mayores se deflacta el ingreso al mes de agosto de 2008 a partir 
del INPC general, y considerando el mes de referencia del ingreso
(ver documentacin del MCS 2008);

*INGRESO MENSUAL (deflactado);

*Las variables mes_1 a mes_6 definen los meses a los que los
respondentes recibieron cada uno de los ingresos reportados.

As, se sabe que la encuesta fue levantada entre los meses de
agosto y noviembre, y por lo tanto, al preguntarse por los
ingresos de los seis meses anteriores, se recolect
informacin correspondiente a los meses de febrero-julio, 
marzo-agosto, abril-septiembre, y mayo-octubre.

*Deflactores 2008;

scalar ene08 = 0.973529049 ;
scalar feb08 = 0.976423103 ;
scalar mar08 = 0.983500031 ;
scalar abr08 = 0.985738100 ;
scalar may08 = 0.984673088 ;
scalar jun08 = 0.988747916 ;
scalar jul08 = 0.994258196 ;
scalar ago08 = 1.000000000 ;
scalar sep08 = 1.006814534 ;
scalar oct08 = 1.013675372 ;
scalar nov08 = 1.025197567 ;
scalar dic08 = 1.032297648 ;

replace ing_6=ing_6/feb08 if mes_6==2;
replace ing_6=ing_6/mar08 if mes_6==3;
replace ing_6=ing_6/abr08 if mes_6==4;
replace ing_6=ing_6/may08 if mes_6==5;

replace ing_5=ing_5/mar08 if mes_5==3;
replace ing_5=ing_5/abr08 if mes_5==4;
replace ing_5=ing_5/may08 if mes_5==5;
replace ing_5=ing_5/jun08 if mes_5==6;

replace ing_4=ing_4/abr08 if mes_4==4;
replace ing_4=ing_4/may08 if mes_4==5;
replace ing_4=ing_4/jun08 if mes_4==6;
replace ing_4=ing_4/jul08 if mes_4==7;

replace ing_3=ing_3/may08 if mes_3==5;
replace ing_3=ing_3/jun08 if mes_3==6;
replace ing_3=ing_3/jul08 if mes_3==7;
replace ing_3=ing_3/ago08 if mes_3==8;

replace ing_2=ing_2/jun08 if mes_2==6;
replace ing_2=ing_2/jul08 if mes_2==7;
replace ing_2=ing_2/ago08 if mes_2==8;
replace ing_2=ing_2/sep08 if mes_2==9;

replace ing_1=ing_1/jul08 if mes_1==7;
replace ing_1=ing_1/ago08 if mes_1==8;
replace ing_1=ing_1/sep08 if mes_1==9;
replace ing_1=ing_1/oct08 if mes_1==10;

* Una vez realizada la deflactacin, se procede a obtener el
ingreso mensual promedio en los ltimos seis meses,
para cada persona y clave de ingreso;

egen ing_pens=rmean(ing_1 ing_2 ing_3 ing_4 ing_5 ing_6) 
   if clave=="P032" | clave=="P033";

egen ing_pam=rmean(ing_1 ing_2 ing_3 ing_4 ing_5 ing_6) 
   if clave=="P044";

recode ing_pens ing_pam (.=0);

collapse (sum) ing_pens ing_pam, by(proyecto folioviv foliohog numren);

label var ing_pens "Ingreso promedio mensual por jubilaciones y pensiones";
label var ing_pam "Ingreso promedio mensual por programas de adultos mayores";

sort proyecto folioviv foliohog numren;

save "$bases\pensiones08.dta", replace;


****************************
*Construccin del indicador*
****************************;

use "$data\poblacion08.dta", clear;

*Poblacin objeto:no se incluye a huspedes ni trabajadores domsticos;

drop if parentesco>=400 & parentesco <500;
drop if parentesco>=700 & parentesco <800;

*Integracin de bases;

sort proyecto folioviv foliohog numren;

merge proyecto folioviv foliohog numren using "$bases\prestaciones08.dta";

tab _merge;
drop _merge;

sort proyecto folioviv foliohog numren;

merge proyecto folioviv foliohog numren using "$bases\pensiones08.dta";

tab _merge;
drop _merge;

*********************************
*PEA (personas de 16 aos o ms)*
*********************************;

gen pea=.;
replace pea=1 if trab==1 & (edad>=16 & edad!=.);
replace pea=2 if bustrab_1==1 & (edad>=16 & edad!=.);
replace pea=0 if (edad>=16 & edad!=.) & bustrab_1==. & 
(bustrab_2==2 | bustrab_3==3 | bustrab_4==4 | bustrab_5==5 | 
bustrab_6==6 | bustrab_7==7);

label var pea "Poblacin econmicamente activa";
label define pea 0 "PNEA" 
                 1 "PEA: ocupada" 
                 2 "PEA: desocupada";
label value pea pea;


*****************
*TIPO DE TRABAJO*
*****************;

* Ocupacin principal;

*Se utilizan las variables tip_trab1 y tip_trab2, las cuales se 
generan en la base de prestaciones08.dta y se 
restringe de acuerdo con la variable pea;

replace tipo_trab1=tipo_trab1 if pea==1;
replace tipo_trab1=. if (pea==0 | pea==2);
replace tipo_trab1=. if pea==.;
label var tipo_trab1 "Tipo de trabajador en ocupacin principal";
label define tipo_trab 1"Depende de un patrn, jefe o superior"
                       2 "No depende de un jefe y tiene asignado un sueldo"
                       3 "No depende de un jefe y no recibe o tiene asignado un sueldo";
label value tipo_trab1 tipo_trab;


*Ocupacin secundaria;

replace tipo_trab2=tipo_trab2 if pea==1;
replace tipo_trab2=. if (pea==0 | pea==2);
replace tipo_trab2=. if pea==.;
label var tipo_trab2 "Tipo de trabajador en ocupacin secundaria";
label value tipo_trab2 tipo_trab;


*************************
*JUBILADOS O PENSIONADOS*
*************************;

gen jub=.;
replace jub=1 if trabajo==2 & bustrab_3==3;
replace jub=1 if ing_pens>0 &  ing_pens!=.;
replace jub=1 if inscr_2==2;
recode jub (.=0);

label var jub "Poblacin pensionada o jubilada";
label define jub 0 "Poblacin no pensionada o jubilada" 
                 1 "Poblacin pensionada o jubilada";
label value jub jub;


**********************
*PRESTACIONES BSICAS*
**********************;

*LABORALES;

*Las prestaciones de incapacidad con goce de sueldo y Afore recibida como
prestacin laboral ya han sido definidas:

Incapacidad con goce de sueldo en ocupacin principal:inclab1
Incapacidad con goce de sueldo ocupacin secundaria: inclab2

Afore por prestacin laboral ocupacin principal: aforlab1
Afore por prestacin laboral ocupacin secundaria: aforlab1;

*Prestaciones laborales (Servicios mdicos);


*Ocupacin principal;

gen smlab1=.;
replace smlab1=1 if ocupa1==1 & atemed==1 & (inst_1==1 | inst_2==2 | inst_3==3 | inst_4==4) 
& (inscr_1==1);
recode smlab1 (.=0) if ocupa1==1;

label var smlab1 "Servicios mdicos por prestacin laboral en ocupacin principal";
label define smlab 0 "Sin servicios mdicos" 
                   1 "Con servicios mdicos";
label value smlab1 smlab;


*Ocupacin secundaria;

gen smlab2=.;
replace smlab2=1 if ocupa2==1 & atemed==1 & (inst_1==1 | inst_2==2 | inst_3==3 | inst_4==4) 
& (inscr_1==1);
recode smlab2 (.=0) if ocupa2==1;

label var smlab2 "Servicios mdicos por prestacin laboral en ocupacin secundaria";
label value smlab2 smlab;

*CONTRATACIN VOLUNTARIA: servicios mdicos y SAR o Afore;

*Servicios mdicos;

gen smcv=.;
replace smcv=1 if atemed==1 & (inst_1==1 | inst_2==2 | inst_3==3 | inst_4==4) 
& (inscr_6==6) & (edad>=12 & edad<=97);
recode smcv (.=0) if (edad>=12 & edad<=97);

label var smcv "Servicios mdicos por contratacin voluntaria";
label define smcv 0 "No cuenta" 
                  1 "S cuenta";
label value smcv smcv;

*SAR o Afore;

gen aforecv=.;
replace aforecv=1 if segvol_1==1 & (edad>=12 & edad!=.);
recode aforecv (.=0) if segvol_1==. &  (edad>=12 & edad!=.);

label var aforecv "SAR o Afore";
label define aforecv 0 "No cuenta " 
                     1 "S cuenta";
label value aforecv aforecv;

***********************************************************************
*INDICADOR DE ACCESO DIRECTO A LA SEGURIDAD SOCIAL
***********************************************************************;

*A partir de la informacin anterior se identificar el acceso directo
a la seguridad social de acuerdo a los siguientes criterios:

-Si es ocupada y en cualquiera de sus trabajos es subordinada y recibe 
como prestacin laboral servicios mdicos, incapacidad con goce de sueldo 
y SAR o Afore.
-Si es ocupada y en cualquiera de sus trabajos es independiente con un sueldo
o pago asignado y dispone de servicios mdicos y SAR o Afore como prestacin 
laboral o por contratacin propia.
-Si es ocupada y en cualquiera de sus trabajos es independiente sin sueldo
o pago asignado y dispone de servicios mdicos como prestacin laboral y 
SAR o Afore por contratacin propia.
-Si es jubilada o pensionada
************************************************************************;

gen ss_dir=.;

*Ocupacin principal;

replace ss_dir=1 if tipo_trab1==1 & (smlab1==1 & inclab1==1 & aforlab1==1);
replace ss_dir=1 if tipo_trab1==2 & ((smlab1==1 | smcv==1) & (aforlab1==1 | aforecv==1));
replace ss_dir=1 if tipo_trab1==3 & ((smlab1==1 | smcv==1) & aforecv==1);

*Ocupacin secundaria;

replace ss_dir=1 if tipo_trab2==1 & (smlab2==1 & inclab2==1 & aforlab2==1);
replace ss_dir=1 if tipo_trab2==2 & ((smlab2==1 | smcv==1) & (aforlab2==1 | aforecv==1));
replace ss_dir=1 if tipo_trab2==3 & ((smlab2==1 | smcv==1) & aforecv==1);

*Jubilados y pensionados;

replace ss_dir=1 if jub==1;
recode ss_dir (.=0);

label var ss_dir "Acceso directo a la seguridad social";
label define ss_dir   0 "Sin acceso"
                      1 "Con acceso";
label value ss_dir ss_dir;


*********************
* NCLEOS FAMILIARES*
*********************;

*En primer lugar se identifican los principales parentescos respecto
a la jefatura del hogar;

gen par=.;
replace par=1 if (parentesco>=100 & parentesco<200);
replace par=2 if (parentesco>=200 & parentesco<300);
replace par=3 if (parentesco>=300 & parentesco<400);
replace par=4 if parentesco==601;
replace par=5 if parentesco==615;
recode par (.=6) if  par==.;

label var par "Integrantes que tienen acceso por otros miembros";
label define par       1 "Jefe o jefa del hogar" 
                       2 "Cnyuge del  jefe/a" 
                       3 "Hijo del jefe/a" 
                       4 "Padre o Madre del jefe/a"
                       5 "Suegro del jefe/a"
                       6 "Sin parentesco directo";
label value par par;

*Asimismo, se utilizar la informacin relativa a la asistencia a la 
escuela;

gen inas_esc=.;
replace inas_esc=0 if asis_esc==1;
replace inas_esc=1 if asis_esc==2;

label var inas_esc "Inasistencia a la escuela";
label define inas_esc  0 "S asiste" 
                       1 "No asiste";
label value inas_esc inas_esc;


*Para la identificacin del acceso a travs de ncleos familiares
se identifica a nivel hogar si los integrantes que pueden otorgar
el acceso disponen del mismo;

* AUXILIARES QUE IDENTIFICAN SI UN MIEMBRO DEL HOGAR CUENTA O NO CON ACCESO A LA SEG SOCIAL*;

*En primer lugar se identifican los principales parentescos respecto
a la jefatura del hogar;

gen jef=1 if par==1 & ss_dir==1;
gen cony=1 if par==2 & ss_dir==1;
gen hijo=1 if par==3 & ss_dir==1 & jub==0;
replace hijo=1 if par==3 & ss_dir==1 & jub==1 & (edad>25 & edad!=.);

egen jef_ss=sum(jef), by(proyecto folioviv foliohog);
egen cony_ss=sum(cony), by(proyecto folioviv foliohog);
replace cony_ss=1 if cony_ss>=1 & cony_ss!=.;
egen hijo_ss=sum(hijo), by(proyecto folioviv foliohog);
replace hijo_ss=1 if hijo_ss>=1 & hijo_ss!=.;

label var jef_ss "Acceso directo a la seguridad social de la jefatura del hogar";
label define jef_ss 0 "No cuenta"
                    1 "S cuenta";
label value jef_ss jef_ss;

label var cony_ss "Acceso directo a la seguridad social de conyuge de la jefatura del hogar";
label define cony_ss 0 "No cuenta"
                     1 "S cuenta";
label value cony_ss cony_ss;

label var hijo_ss "Acceso directo a la seguridad social de hijos(as) de la jefatura del hogar";
label define hijo_ss 0 "No cuenta"
                     1  "S cuenta";
label value hijo_ss hijo_ss;


**************************
* OTROS NCLEOS FAMILIARES
**************************;

*Asimismo, se identifica a la poblacin con acceso a la seguridad
social mediante otros ncleos familiares a travs de la afiliacin
o inscripcin a servicios de salud por algn familiar dentro o 
fuera del hogar, muerte del asegurado o por contratacin propia;

gen s_salud=.;
replace s_salud=1 if atemed==1 & (inst_1==1 | inst_2==2 | inst_3==3 | inst_4==4) 
& (inscr_3==3 | inscr_4==4 | inscr_6==6 | inscr_7==7);
recode s_salud (.=0) if segpop!=. & atemed!=.;

label var s_salud "Servicios mdicos por otros ncleos familiares o por contratacin propia";
label define s_salud  0 "No cuenta"
                      1  "S cuenta";
label value s_salud s_salud;


**************************************************
*PROGRAMAS SOCIALES DE PENSIONES PARA ADULTOS MAYORES *
***************************************************;

gen pam=.;
replace pam=1 if (edad>=65 & edad!=.) & ing_pam>0 & ing_pam!=.;
recode pam (.=0) if (edad>=65 & edad!=.) ;

label var pam "Programa de adultos mayores";
label define pam 0 "No recibe" 
                 1 "Recibe";
label value pam pam;


***********************************************************************
*
* INDICADOR DE CARENCIA POR ACCESO A LA SEGURIDAD SOCIAL
*
***********************************************************************

No se considera en situacin de carencia por acceso a la seguridad social
a la poblacin que:

1. Disponga de acceso directo a la seguridad social,
2. Cuente con parentesco directo con alguna persona dentro del hogar
que tenga acceso directo,
3. Reciba servicios mdicos por parte de algn familiar dentro o
fuera del hogar, por muerte del asegurado o por contratacin propia, o,
4. Reciba ingresos por parte de un programa de adultos mayores. 

Se considera en situacin de carencia por acceso a la seguridad social
aquella poblacin:

1. En cualquier otra situacin.
***********************************************************************;

gen ic_segsoc=.;

*Acceso directo;

replace ic_segsoc=0 if ss_dir==1;

*Parentesco directo: jefatura;

replace ic_segsoc=0 if par==1 & cony_ss==1;
replace ic_segsoc=0 if par==1 & pea==0 & hijo_ss==1;

*Parentesco directo: cnyuge;

replace ic_segsoc=0 if par==2 & jef_ss==1;
replace ic_segsoc=0 if par==2 & pea==0 & hijo_ss==1;

*Parentesco directo: descendientes;

replace ic_segsoc=0 if par==3 & edad<16 & jef_ss==1;
replace ic_segsoc=0 if par==3 & edad<16 & cony_ss==1;

replace ic_segsoc=0 if par==3 & (edad>=16 & edad<=25) & inas_esc==0 & jef_ss==1;
replace ic_segsoc=0 if par==3 & (edad>=16 & edad<=25) & inas_esc==0 & cony_ss==1;

*Parentesco directo: ascendientes;

replace ic_segsoc=0 if par==4 & pea==0 & jef_ss==1;
replace ic_segsoc=0 if par==5 & pea==0 & cony_ss==1;

*Otros ncleos familiares;

replace ic_segsoc=0 if s_salud==1;

*Programa de adultos mayores;

replace ic_segsoc=0 if pam==1;
recode ic_segsoc (.=1);

label var ic_segsoc "Indicador de carencia por acceso a la seguridad social";
label define ic_segsoc 0 "Con acceso"
	      		1 "Sin acceso";
label value ic_segsoc ic_segsoc;

keep proyecto folioviv foliohog numren tipo_trab*  inclab*  aforlab* smlab* smcv 
aforecv pea jub ss_dir par jef_ss cony_ss hijo_ss s_salud pam ic_segsoc;

sort proyecto folioviv foliohog numren;

save "$bases\ic_segsoc08.dta", replace;


*********************************************************

Parte IV Indicadores de Privacin social:

INDICADOR DE CARENCIA POR CALIDAD Y ESPACIOS EN LA VIVIENDA

*********************************************************;

*Para la construccin del indicador de carencia por calidad
y espacios de la vivienda se utilizan las variables de material
de pisos, material de techos, material de muros, nmero de cuartos
en la vivienda y total de residentes en la vivienda.
*********************************************************;

****************************************
MATERIAL DE CONSTRUCCIN DE LA VIVIENDA
****************************************;


use "$data\hogares08.dta", clear;

*En los casos donde hay ms de un hogar en la vivienda, la informacin
a nivel vivienda slo reporta para los hogares principales, por lo cual 
se imputa la caracterstica correspondiente a los hogares secundarios;


sort proyecto folioviv foliohog;

save "$data\hogares08.dta", replace;

use "$data\concentrado08.dta", clear;

sort proyecto folioviv foliohog;

merge proyecto folioviv foliohog using "$data\hogares08.dta";

tab _merge;
drop _merge;

*Definicin de variables;

*MATERIAL DE LOS PISOS DE LA VIVIENDA;

recode pisos (-1=.);
egen pisov=sum(pisos), by(proyecto folioviv);
recode pisov (0=.);

gen cv_pisos=.;

replace cv_pisos=1 if pisov==1;
replace cv_pisos=2 if pisov==2;
replace cv_pisos=3 if pisov==3;
replace cv_pisos=4 if pisov==4;
replace cv_pisos=5 if pisov==5;
replace cv_pisos=6 if pisov==6;

label var cv_pisos "Material de los pisos";
label define cv_pisos 1 "Tierra" 
                      2 "Cemento o firme" 
                      3 "Linleum,congleum o vinil" 
                      4 "Piso laminado" 
                      5 "Mosaico, mrmol o vitropiso" 6 "Madera, duela o parquet";
label value cv_pisos cv_pisos;

*MATERIAL DE LOS TECHOS DE LA VIVIENDA;

egen techov=sum(techos), by(proyecto folioviv);
recode techov (0=.);

gen cv_techos=.;

replace cv_techos=1 if techov==1;
replace cv_techos=2 if techov==2;
replace cv_techos=3 if techov==3;
replace cv_techos=4 if techov==4;
replace cv_techos=5 if techov==5;
replace cv_techos=6 if techov==6;
replace cv_techos=7 if techov==8;
replace cv_techos=8 if techov==7;
replace cv_techos=9 if techov==9;

label var cv_techos "Material de techos";
label define cv_techos 1 "Desecho" 
                       2 "Lmina de cartn" 
                       3 "Lmina metlica" 
                       4 "Lmina de asbesto" 
                       5 "Palma o paja" 
                       6 "Madera o tejamanil" 
                       7 "Teja" 
                       8 "Terrado con viguera" 
                       9 "Loseta de concreto o viguetas con bovedilla";
label value cv_techos cv_techos;

*MATERIAL DE MUROS EN LA VIVIENDA;

egen murov=sum(pared), by(proyecto folioviv);
recode murov (0=.);

gen cv_muros=.;

replace cv_muros=1 if murov==1;
replace cv_muros=2 if murov==2;
replace cv_muros=3 if murov==3;
replace cv_muros=4 if murov==4;
replace cv_muros=5 if murov==5;
replace cv_muros=6 if murov==6;
replace cv_muros=7 if murov==7;
replace cv_muros=8 if murov==8;

label var cv_muros "Material de muros";
label define cv_muros 1 "Desecho" 
                      2 "Lmina de cartn" 
                      3 "Lmina metlica o de asbesto" 
                      4 "Carrizo, bamb o palma" 
                      5 "Embarro o bajareque" 
                      6 "Madera" 
                      7 "Adobe" 
                      8 "Tabique, ladrillo, block, piedra o concreto";
label value cv_muros cv_muros;

**************************
* ESPACIOS EN LA VIVIENDA
**************************;

*NDICE DE HACINAMIENTO;

* Nmero de residentes en la vivienda;

egen num_ind=sum(tot_resi), by(proyecto folioviv);
recode num_ind (0=.);
label var num_ind "Nmero de residentes en la vivienda";

* Nmero de cuartos en la vivienda;

egen num_cua=sum(cuart), by(proyecto folioviv);
recode num_cua (0=.);
label var num_cua "Nmero de cuartos de la vivienda";

gen cv_hac=num_ind/num_cua;
label var cv_hac "ndice de hacinamiento de la vivienda";

*A partir de las variables anteriores se construyen los sub-indicadores
que componen al indicador de carencia de esta dimensin;

*INDICADOR DE CARENCIA DEL MATERIAL DE PISOS EN LA VIVIENDA;

gen icv_pisos=.;
replace icv_pisos=1 if cv_pisos==1;
replace icv_pisos=0 if cv_pisos>1 & cv_pisos!=.;

label var icv_pisos "Indicador de carencia del material de piso de la vivienda";
label define icv_pisos 0 "Sin carencia"
                       1 "Con carencia";
label value icv_pisos icv_pisos;


*INDICADOR DE CARENCIA DEL MATERIAL DE TECHOS EN LA VIVIENDA;

gen icv_techos=.;
replace icv_techos=1 if cv_techos<=2;
replace icv_techos=0 if cv_techos>2 & cv_techos!=.;

label var icv_techos "Indicador de carencia por material de techos de la vivienda";
label define icv_techos 0 "Sin carencia"
                        1 "Con carencia";
label value icv_techos icv_techos;


*INDICADOR DE CARENCIA DEL MATERIAL DE MUROS EN LA VIVIENDA;

gen icv_muros=.;
replace icv_muros=1 if cv_muros<=5;
replace icv_muros=0 if cv_muros>5 & cv_muros!=.;

label var icv_muros "Indicador de carencia del material de muros de la vivienda";
label define icv_muros 0 "Sin carencia"
                       1 "Con carencia";
label value icv_muros icv_muros;


*INDICADOR DE CARENCIA POR NDICE DE HACINAMIENTO;

gen icv_hac=.;
replace icv_hac=1 if cv_hac>2.5;
replace icv_hac=0 if cv_hac<=2.5 & cv_hac!=.;

label var icv_hac "Indicador de carencia por ndice de hacinamiento de la vivienda";
label define icv_hac 0 "Sin carencia"
                     1 "Con carencia";
label value icv_hac icv_hac;


*********************************************************
*
* INDICADOR DE CARENCIA POR CALIDAD Y ESPACIOS DE LA VIVIENDA
*
***********************************************************;

*Se considera en situacin de carencia por calidad y espacios 
de la vivienda a la poblacin que:

1. Presente carencia en cualquiera de los subindicadores de esta dimensin

No se considera en situacin de carencia por rezago calidad y espacios 
de la vivienda a la poblacin que:

1. Habite en una vivienda sin carencia en todos los subindicadores
de esta dimensin
*************************************************************;

gen ic_cv=.;
replace ic_cv=1 if icv_pisos==1 | icv_techos==1 | icv_muros==1 | icv_hac==1;
replace ic_cv=0 if icv_pisos==0 & icv_techos==0 & icv_muros==0 & icv_hac==0;
replace ic_cv=. if icv_pisos==. | icv_techos==. | icv_muros==. | icv_hac==.;

label var ic_cv "Indicador de carencia por calidad y espacios de la vivienda";
label define ic_cv 0 "Sin carencia"
      		     1 "Con carencia";
label value ic_cv ic_cv;

sort proyecto folioviv foliohog;

keep proyecto folioviv foliohog cv_pisos cv_techos cv_muros num_ind num_cua 
cv_hac icv_pisos icv_techos icv_muros icv_hac ic_cv;

save "$bases\ic_cev08.dta", replace;
 

*********************************************************

Parte V Indicadores de Privacin Social:

INDICADOR DE CARENCIA POR ACCESO A LOS SERVICIOS BSICOS EN LA VIVIENDA

*********************************************************;

use "$data\hogares08.dta", clear;

*Para la construccin del indicador de carencia por servicios bsicos 
en la vivienda  se utiliza informacin sobre la disponibilidad
de los servicios de electricidad, agua y drenaje.

*En los casos donde hay ms de un hogar en la vivienda, la informacin
a nivel vivienda slo reporta para los hogares principales, por lo cual 
se imputa la caracterstica correspondiente a los hogares secundarios.

*Definicin de variables;

*ACCESO AL AGUA EN LA VIVIENDA;

egen aguav=sum(agua13), by(proyecto folioviv);
recode aguav (0=.);

gen sb_agua=.;
replace sb_agua=1 if aguav==6 | aguav==7;
replace sb_agua=2 if aguav==5;
replace sb_agua=3 if aguav==3;
replace sb_agua=4 if aguav==4;
replace sb_agua=5 if aguav==2;
replace sb_agua=6 if aguav==1;

label var sb_agua "Acceso al agua";
label define sb_agua 1 "Pozo, ro, lago, arroyo u otro" 
                     2 "Pipa" 
                     3 "Entubada que acarrea de otra vivienda" 
                     4 "Entubada de la llave pblica o hidrante" 
                     5 "Entubada fuera de la vivienda pero dentro del terreno" 
                     6 "Entubada dentro de la vivienda";
label value sb_agua sb_agua;


*ACCESO AL SERVICIO DE DRENAJE EN LA VIVIENDA;

egen drenajev=sum(drenaje), by(proyecto folioviv);
recode drenajev (0=.);

gen sb_dren=.;
replace sb_dren=1 if drenajev==5;
replace sb_dren=2 if drenajev==4;
replace sb_dren=3 if drenajev==3;
replace sb_dren=4 if drenajev==2;
replace sb_dren=5 if drenajev==1;

label var sb_dren "Servicio de drenaje";
label define sb_dren 1 "No tiene drenaje" 
                     2 "Conectado a una tubera que va a dar a un ro, lago o mar" 
                     3 "Conectado a una tubera que va a dar a una barranca o grieta" 
                     4 "Conectado a una fosa sptica" 
                     5 "Conectado a la red pblica";
label value sb_dren sb_dren;

*ACCESO AL SERVICIO DE ELECTRICIDAD;

egen elecv=sum(elect), by(proyecto folioviv);
recode elecv (0=.);

gen sb_luz=.;
replace sb_luz=1 if elecv==5;
replace sb_luz=2 if elecv==3 | elecv==4;
replace sb_luz=3 if elecv==2;
replace sb_luz=4 if elecv==1;

label var sb_luz "Servicio de electricidad";
label define sb_luz         1 "No tiene luz elctrica" 
                            2 "Panel solar u otra fuente" 
                            3 "Planta particular" 
                            4 "Servicio pblico";
label value sb_luz sb_luz;

*A partir de las variables anteriores se construyen los sub-indicadores
que componen el indicador de carencia de esta dimensin;

gen isb_agua=1 if sb_agua<=4;
replace isb_agua=0 if sb_agua>4 & sb_agua!=.;

label var isb_agua "Indicador de carencia de acceso al agua";
label define icv_agua 0 "Sin carencia"
                      1 "Con carencia";
label value isb_agua icv_agua;


gen isb_dren=1 if sb_dren<=3;
replace isb_dren=0 if sb_dren>3 & sb_dren!=.;

label var isb_dren "Indicador de carencia de servicio de drenaje";
label define icv_dren 0 "Sin carencia"
                      1 "Con carencia";
label value isb_dren icv_dren;


gen isb_luz=1 if sb_luz==1;
replace isb_luz=0 if sb_luz>1 & sb_luz!=.;

label var isb_luz "Indicador de carencia de servicios de electricidad";
label define icv_luz 0 "Sin carencia"
                     1 "Con carencia";
label value isb_luz icv_luz;

*****************************************************************
*
* INDICADOR DE CARENCIA POR DE ACCESO A SERVICIOS BSICOS DE LA VIVIENDA
*
*******************************************************************;
*Se considera en situacin de carencia por servicios bsicos en la vivienda a la poblacin que:

1. Presente carencia en cualquiera de los subindicadores de esta dimensin.

No se considera en situacin de carencia por  servicios bsicos en la vivienda a la poblacin que:

1. Habite en una vivienda sin carencia en todos los subindicadores de esta dimensin

***********************************************************************;

gen ic_sbv=.;
replace ic_sbv=1 if (isb_agua==1 | isb_dren==1 | isb_luz==1);
replace ic_sbv=0 if isb_agua==0 & isb_dren==0 & isb_luz==0;
replace ic_sbv=. if (isb_agua==. | isb_dren==. | isb_luz==.);

label var ic_sbv "Indicador de carencia de acceso a servicios bsicos de la vivienda";
label define ic_sbv  0 "Sin carencia" 
                     1 "Con carencia";
label value ic_sbv ic_sbv;

sort proyecto folioviv foliohog;

keep proyecto folioviv foliohog  sb_agua sb_dren sb_luz isb_agua 
isb_dren isb_luz ic_sbv;

save "$bases\ic_sbv08.dta", replace;


**********************************************************************
 Parte VI Indicadores de Privacin Social:

 INDICADOR DE CARENCIA POR ACCESO A LA ALIMENTACIN

**********************************************************************;
*Esta escala incluye 12 preguntas que se diferencian por los miembros del hogar, esto es:
hogares donde habitan menores de 18 aos y hogares donde NO habitan menores de 18 aos.

**********************************************************************;

*Definicin de variables;

use "$data\poblacion08.dta", clear;
 
*Poblacin objeto: no se incluye a huspedes ni trabajadores domsticos;

drop if parentesco>=400 & parentesco <500;
drop if parentesco>=700 & parentesco <800;

*INDICADOR DE HOGARES CON INTEGRANTES MENORES DE 18 AOS;

gen men=1 if edad>=0 & edad<=17;
collapse (sum) men, by(proyecto folioviv foliohog);

gen id_men=.;
replace id_men=1 if men>=1 & men!=.;
replace id_men=0 if men==0;


label var id_men "Hogares con poblacin de 0 a 17 aos de edad";
label define id_men 0 "Sin poblacin de 0 a 17 aos"
                    1 "Con poblacin de 0 a 17 aos";
label value id_men id_men;

sort proyecto folioviv foliohog;

keep proyecto folioviv foliohog  id_men;

save "$bases\menores08.dta", replace;


********************************
 ESCALA DE INSEGURIDAD ALIMENTARIA
*********************************;

use "$data\hogares08.dta", clear;

* SEIS PREGUNTAS PARA HOGARES SIN POBLACIN MENOR A 18 AOS;

recode alim1 (2=0) (1=1), gen (ia_1ad);
recode alim2 (2=0) (1=1), gen (ia_2ad);
recode alim3 (2=0) (1=1), gen (ia_3ad);
recode alim4 (2=0) (1=1), gen (ia_4ad);
recode alim5 (2=0) (1=1), gen (ia_5ad);
recode alim6 (2=0) (1=1), gen (ia_6ad);

label var ia_1ad "Algn adulto tuvo una alimentacin basada en muy poca variedad de alimentos";
label define si_no 1 "S" 0 "No";
label value ia_1ad si_no;

label var ia_2ad "Algn adulto dej de desayunar, comer o cenar";
label value ia_2ad si_no;

label var ia_3ad "Algn adulto comi menos de lo que deba comer";
label value ia_3ad si_no;

label var ia_4ad "El hogar se qued sin comida";
label value ia_4ad si_no;

label var ia_5ad "Algn adulto sinti hambre pero no comi";
label value ia_5ad si_no;

label var ia_6ad "Algn adulto solo comi una vez al da o dej de comer todo un da";
label value ia_6ad si_no;


* SEIS PREGUNTAS PARA HOGARES CON POBLACIN MENOR A 18 AOS;

recode alim7 (2=0) (1=1), gen (ia_7men);
recode alim8 (2=0) (1=1), gen (ia_8men);
recode alim9 (2=0) (1=1), gen (ia_9men);
recode alim10 (2=0) (1=1), gen (ia_10men);
recode alim11 (2=0) (1=1), gen (ia_11men);
recode alim12 (2=0) (1=1), gen (ia_12men);

label var ia_7men "Alguien de 0 a 17 aos tuvo una alimentacin basada en muy poca variedad de alimentos";
label value ia_7men si_no;

label var ia_8men "Alguien de 0 a 17 aos comi menos de lo que deba";
label value ia_8men si_no;

label var ia_9men "Se tuvo que disminuir la cantidad servida en las comidas a alguien de 0 a 17 aos";
label value ia_9men si_no;

label var ia_10men "Alguien de 0 a 17 aos sinti hambre pero no comi";
label value ia_10men si_no;

label var ia_11men "Alguien de 0 a 17 aos se acost con hambre";
label value ia_11men si_no;

label var ia_12men "Alguien de 0 a 17 aos comi una vez al da o dej de comer todo un da";
label value ia_12men si_no;


*CONTRUCCIN DE LA ESCALA DE INSEGURIDAD ALIMENTARIA;

*Para construir la escala se requiere distinguir entre aquellos hogares
con poblacin de 0 a 17 aos y los que no cientan con integrantes de esa
edad;

sort proyecto folioviv foliohog;

merge proyecto folioviv foliohog using "$bases\menores08.dta";

tab _merge;
drop _merge;

*A partir de la escala se define el grado de inseguridad alimentaria de la siguiente forma:

-Se considera sin inseguridad alimentaria a los hogares con o sin poblacin 
de 0 a 17 aos que no reportaron respuestas afirmativas

-Se consideran con inseguridad alimentaria leve a los hogares que no tienen
poblacin de 0 a 17 aos y que respondieron afirmativamente a un mximo de
dos preguntas de la escala

-Se consideran con inseguridad alimentaria leve a los hogares que cuentan con
poblacin de 0 a 17 aos y que respondieron afirmativamente a un mximo de
tres preguntas de la escala

-Se consideran con inseguridad alimentaria moderada a los hogares que no 
tienen poblacin de 0 a 17 aos y que respondieron afirmativamente a tres 
o cuatro preguntas de la escala

-Se consideran con inseguridad alimentaria moderada a los hogares que cuentan 
con poblacin de 0 a 17 aos y que respondieron afirmativamente de cuatro a 
siete preguntas de la escala

-Se consideran con inseguridad alimentaria grave a los hogares que no 
tienen poblacin de 0 a 17 aos y que respondieron afirmativamente a cinco 
o ms preguntas de la escala

-Se consideran con inseguridad alimentaria moderada a los hogares que cuentan 
con poblacin de 0 a 17 aos y que respondieron afirmativamente a ocho o ms 
preguntas de la escala;

*ESCALA PARA HOGARES SIN MENORES DE 18 AOS;

gen tot_iaad=.;
replace tot_iaad=ia_1ad + ia_2ad + ia_3ad +ia_4ad + ia_5ad+ ia_6ad if id_men==0;
label var tot_iaad "Escala de IA para hogares sin menores de 18 aos";

*ESCALA PARA HOGARES CON MENORES DE 18 AOS;

gen tot_iamen=.;
replace tot_iamen=ia_1ad + ia_2ad + ia_3ad +ia_4ad + ia_5ad+ ia_6ad+ia_7men + ia_8men + ia_9men+ia_10men + ia_11men+ia_12men if id_men==1;
label var tot_iamen "Escala IA para hogares con menores de 18 aos ";


********************************************************
* GRADO DE INSEGURIDAD ALIMENTARIA
*
* Este subindicador genera cuatro clasificaciones de la siguiente forma:
* + Sin inseguridad alimentaria
* + Inseguridad alimentaria leve
* + Inseguridad alimentaria moderada
* + Inseguridad alimentaria severa
************************************************************;

gen ins_ali=.;
replace ins_ali=0 if tot_iaad==0 | tot_iamen==0;
replace ins_ali=1 if (tot_iaad==1 | tot_iaad==2) | (tot_iamen==1 | tot_iamen==2 |tot_iamen==3);
replace ins_ali=2 if  (tot_iaad==3 | tot_iaad==4) | (tot_iamen==4 | tot_iamen==5 |tot_iamen==6 |tot_iamen==7);
replace ins_ali=3 if (tot_iaad==5 | tot_iaad==6) | (tot_iamen>=8 & tot_iamen!=.) ;

label var  ins_ali "Grado de inseguridad alimentaria";
label define  ins_ali 0 "Seguridad alimentaria"
                      1 "Inseguridad alimentaria leve"
                      2 "Inseguridad alimentaria moderada"
                      3 "Inseguridad alimentaria severa";
label value ins_ali ins_ali;


*********************************************************
*
* INDICADOR DE CARENCIA POR ACCESO A LA ALIMENTACIN
*
***********************************************************;
*Se considera en situacin de carencia por acceso a la alimentacin 
a la poblacin en hogares que:

1. Presenten inseguridad alimentaria moderada o severa.

No se considera en situacin de carencia por acceso a la alimentacin 
a la poblacin que:

1. No presente inseguridad alimentaria o un grado de inseguridad 
alimentaria leve.;
***********************************************************************;

gen ic_ali=.;
replace ic_ali=1 if ins_ali==2 | ins_ali==3;
replace ic_ali=0 if ins_ali==0 | ins_ali==1;

label var ic_ali "Indicador de carencia por acceso a la alimentacin";
label define ic_ali 1 "Con carencia"
                    0 "Sin carencia";
label value ic_ali ic_ali;

sort proyecto folioviv foliohog;

keep proyecto folioviv foliohog id_men   ia_*  tot_iaad tot_iamen ins_ali ic_ali;

save "$bases\ic_ali08.dta", replace;


*********************************************************

Parte VII Bienestar (ingresos)

*********************************************************;

*Para la construccin del ingreso corriente del hogar es necesario utilizar
informacin sobre la condicin de ocupacin y los ingresos de los individuos.
Se utiliza la informacin contenida en las bases "$bases\trabajo108.dta" y 
"$bases\trabajo208.dta" para identificar a la poblacin ocupada que declara 
tener como prestacin laboral aguinaldo, ya sea por su trabajo principal o 
secundario, a fin de incorporar los ingresos por este concepto en la medicin;

********************************************************

Creacin del ingreso monetario deflactado a pesos de 
agosto del 2008.

********************************************************;

*Ingresos;

*En primer lugar se mantienen los ingresos por concepto de la clave "P009"
(ingresos por aguinaldo) nicamente para los trabajadores que en el momento 
de la entrevista tenan derecho a esa prestacin en cualquiera de los empleos
reportados. Para ello, se utiliza la base de trabajos08.dta, la cual luego 
se une a la base de ingresos;

use "$data\trabajos08.dta", clear;

keep proyecto folioviv foliohog numren numtrab pres_2;

reshape wide pres_2, i(proyecto folioviv foliohog numren) j( numtrab);

gen trab=1;

label var trab "Poblacin con al menos un empleo";

gen aguinaldo=.;
replace aguinaldo=1 if pres_21==2 | pres_22==2;
recode aguinaldo (.=0);

label var aguinaldo "Aguinaldo";
label define aguinaldo 0 "No dispone de aguinaldo"
                       1 "Dispone de aguinaldo";
label value aguinaldo aguinaldo;

keep proyecto folioviv foliohog numren aguinaldo trab;

sort proyecto folioviv foliohog numren ;

save "$bases\aguinaldo.dta", replace;

*Ahora se incorpora a la base de ingresos;

use "$data\ingresos08.dta", clear;

sort proyecto folioviv foliohog numren;

merge proyecto folioviv foliohog numren using "$bases\aguinaldo.dta";

tab _merge;
drop _merge;

sort proyecto folioviv foliohog numren;

drop if clave=="P009" & aguinaldo!=1;

*Una vez realizado lo anterior, se procede a deflactar el ingreso recibido
por los hogares a precios de agosto de 2008. Para ellos se utilizan las 
variables meses, las cuales toman los valores 2 a 10 e indican el mes en
que se recibi el ingreso respectivo;

*Definicin de los deflactores 2008;

scalar dic07	=	0.969037000	;
scalar ene08	=	0.973529049	;
scalar feb08	=	0.976423103	;
scalar mar08	=	0.983500031	;
scalar abr08	=	0.985738100	;
scalar may08	=	0.984673088	;
scalar jun08	=	0.988747916	;
scalar jul08	=	0.994258196	;
scalar ago08	=	1.000000000	;
scalar sep08	=	1.006814534	;
scalar oct08	=	1.013675372	;
scalar nov08	=	1.025197567	;
scalar dic08	=	1.032297648	;

replace ing_6=ing_6/feb08 if mes_6==2;
replace ing_6=ing_6/mar08 if mes_6==3;
replace ing_6=ing_6/abr08 if mes_6==4;
replace ing_6=ing_6/may08 if mes_6==5;

replace ing_5=ing_5/mar08 if mes_5==3;
replace ing_5=ing_5/abr08 if mes_5==4;
replace ing_5=ing_5/may08 if mes_5==5;
replace ing_5=ing_5/jun08 if mes_5==6;

replace ing_4=ing_4/abr08 if mes_4==4;
replace ing_4=ing_4/may08 if mes_4==5;
replace ing_4=ing_4/jun08 if mes_4==6;
replace ing_4=ing_4/jul08 if mes_4==7;

replace ing_3=ing_3/may08 if mes_3==5;
replace ing_3=ing_3/jun08 if mes_3==6;
replace ing_3=ing_3/jul08 if mes_3==7;
replace ing_3=ing_3/ago08 if mes_3==8;

replace ing_2=ing_2/jun08 if mes_2==6;
replace ing_2=ing_2/jul08 if mes_2==7;
replace ing_2=ing_2/ago08 if mes_2==8;
replace ing_2=ing_2/sep08 if mes_2==9;

replace ing_1=ing_1/jul08 if mes_1==7;
replace ing_1=ing_1/ago08 if mes_1==8;
replace ing_1=ing_1/sep08 if mes_1==9;
replace ing_1=ing_1/oct08 if mes_1==10;

*Se deflactan las claves P008 (Reparto de utilidades) 
y P009 (aguinaldo)
con los deflactores de mayo a agosto 2008 
y de dicembre de 2007 a agosto2008, 
respectivamente, y se obtiene el promedio mensual.;

replace ing_1=(ing_1/may08)/12 if clave=="P008";
replace ing_1=(ing_1/dic07)/12 if clave=="P009";

*Una vez realizada la deflactacin, se procede a obtener el 
ingreso mensual promedio en los ltimos seis meses, para 
cada persona y clave de ingreso;

recode ing_2 ing_3 ing_4 ing_5 ing_6 (0=.) if clave=="P008" | clave=="P009";

egen double ing_mens=rmean(ing_1 ing_2 ing_3 ing_4 ing_5 ing_6);

*Para obtener el ingreso corriente monetario, se seleccionan 
las claves de ingreso correspondientes;

gen double ing_mon=ing_mens if (clave>="P001" & clave<="P009") | (clave>="P011" & clave<="P013") 
                             | (clave>="P015" & clave<="P018") | (clave>="P020" & clave<="P045") 
                             | (clave=="P063") | (clave>="P067" & clave<="P080");

*Se estima el total de ingresos de cada  hogar y fuente 
de ingreso, y se guarda la base en un archivo aparte;

collapse (sum) ing_mon, by(proyecto folioviv foliohog);

label var ing_mon "Ingreso corriente monetario del hogar";

sort proyecto folioviv foliohog;

save "$bases\ingreso_deflactado08.dta", replace;

*********************************************************

Creacin del ingreso no monetario deflactado a pesos de 
agosto del 2008.

*********************************************************;

*No Monetario;

use "$data\nomonetarioe08.dta", clear;

sort proyecto folioviv foliohog;

save "$bases\nomonetarioef08.dta", replace;

use "$data\nomonetariom08.dta", clear;

rename frec frecu;

sort proyecto folioviv foliohog;

save "$bases\nomonetariomf08.dta", replace;

use "$bases\nomonetarioef08.dta", clear;
merge proyecto folioviv foliohog using "$bases\nomonetariomf08.dta";
tab _merge;
drop _merge;

save "$bases\nomonetario08.dta", replace;

use "$bases\nomonetario08.dta", clear;

*En el caso de la informacin de gasto no monetario, para 
deflactar se utiliza la decena de levantamiento de la 
encuesta, la cual se encuentra en la tercera posicin del 
folio de la vivienda. En primer lugar se obtiene una variable que 
identifique la decena de levantamiento;

gen decena=real(substr(folioviv,3,1));

*Al comparar con la informacin del catlogo, se observa que la 
informacin se levant en nueve decenas, correspondientes a:

Decena |	Periodo de levantamiento 	Periodo de referencia de mes pasado 
0	 |	11-17 de Agosto 			Julio 
1	 |	21-27 de Agosto 			Julio 
2	 |	31-06 de Septiembre 		Agosto 
3	 |	10-16 de Septiembre 		Agosto 
4	 |	20-26 Septiembre 			Agosto 
5	 |	30-06 de Octubre 			Septiembre 
6	 |	10-16 de Octubre 			Septiembre 
7	 |	20-26 de Octubre 			Septiembre 
8	 |	30-05 de Noviembre 	      Octubre 
9	 |	09-15 de Noviembre 	      Octubre 


As, para realizar el anlisis, y conforme a lo establecido 
en la informacin de la ENIGH2008, se tomarn como periodos 
de referencia:

Decena	|	Periodo de referencia
		/Semanal	/Mensual	/Trimestral	/Semestral

0     	|	/Agosto	/Julio	/Mayo a julio	/Febrero a julio
1     	|	/Agosto	/Julio	/Mayo a julio	/Febrero a julio
2     	|	/Agosto	/Agosto	/Junio a agosto	/Marzo a agosto
3     	|	/Septiembre	/Agosto	/Junio a agosto	/Marzo a agosto
4     	|	/Septiembre	/Agosto	/Junio a agosto	/Marzo a agosto
5     	|	/Septiembre	/Septiembre	/Julio a septiembre	/Abril a septiembre
6     	|	/Octubre	/Septiembre	/Julio a septiembre	/Abril a septiembre
7     	|	/Octubre	/Septiembre	/Julio a septiembre	/Abril a septiembre
8     	|	/Octubre	/Octubre	/Agosto a octubre	/Mayo a octubre
9     	|	/Noviembre	/Octubre	/Agosto a octubre	/Mayo a octubre

*Los rubros a considerar sern:

Rubro	/Periodicidad	/Nombre del deflactor
Alimentos y bebidas no alcohlicas	/Semanal	/d11wmes
Bebidas alcohlicas y tabaco	/Semanal	/d12wmes
Vestido y calzado	/Trimestral	/d2tmesini
Vivienda y servicios de conservacin	/Mensual	/d3mmes
Estimacin del alquiler	/No se deflactar	/No se deflactar
Artculos y servicios de limpieza	/Mensual	/d42mmes
Cristalera y utensilios domsticos	/Trimestral	/d42tmesini
Enseres domsticos y muebles	/Semestral	/d41smesini
Cuidados de la salud	/Trimestral	/d51tmesini
Transporte pblico	/Semanal	/d611wmes
Transporte forneo	/Semestral	/d6smesini
Comunicaciones	/Mensual	/d6mmes
Educacin bsica	/Mensual	/d7mmes
Cuidado personal	/Mensual	/d23mmes
Accesorios personales	/Trimestral	/d23tmesini
Otros gastos y transferencias	/Semestral	/dINPCsmesini
Regalos otorgados	/Semestral	/dINPCsmesini

*Definicin de los deflactores;

*Rubro 1.1 semanal, Alimentos;

scalar d11w07=	0.992849335	;
scalar d11w08=	1.000000000	;
scalar d11w09=	1.007547538	;
scalar d11w10=	1.013695578	;
scalar d11w11=	1.031951707	;

*Rubro 1.2 semanal, Bebidas alcohlicas y tabaco;

scalar d12w07=	0.9932201	;
scalar d12w08=	1.000000000	;
scalar d12w09=	1.004577412	;
scalar d12w10=	1.006356646	;
scalar d12w11=	1.009037254	;

*Rubro 2 trimestral, Ropa, calzado y accesorios;

scalar d2t05	=	0.995665531	;
scalar d2t06	=	0.996958756	;
scalar d2t07	=	0.999047098	;
scalar d2t08	=	1.002728766	;

*Rubro 3 mensual, Vivienda;

scalar d3m07	=	0.9958319	;
scalar d3m08	=	1	;
scalar d3m09	=	1.0030142	;
scalar d3m10	=	1.0168688	;
scalar d3m11	=	1.0365948	;

*Rubro 4.2 mensual, Accesorios y artculos de limpieza para el hogar;

scalar d42m07	=	0.991289243	;
scalar d42m08	=	1	;
scalar d42m09	=	1.013674952	;
scalar d42m10	=	1.02126174	;
scalar d42m11	=	1.027860798	;

*Rubro 4.2 trimestral, Accesorios y artculos de limpieza para el hogar;

scalar d42t05	=	0.984148069	;
scalar d42t06	=	0.992234399	;
scalar d42t07	=	1.001654732	;
scalar d42t08	=	1.011645564	;

*Rubro 4.1 semestral, Muebles y aparatos dmesticos;

scalar d41s02	=	0.992557573	;
scalar d41s03	=	0.995164752	;
scalar d41s04	=	0.996819338	;
scalar d41s05	=	0.998708459	;

*Rubro 5.1 trimestral, Salud;

scalar d51t05	=	0.996679643	;
scalar d51t06	=	0.998782369	;
scalar d51t07	=	1.000350038	;
scalar d51t08	=	1.00260528	;

*Rubro 6.1.1 semanal, Transporte pblico urbano;

scalar d611w07	=	0.980054808	;
scalar d611w08	=	1	;
scalar d611w09	=	1.016238497	;
scalar d611w10	=	1.020556684	;
scalar d611w11	=	1.027320837	;

*Rubro 6 mensual, Transporte;

scalar d6m07	=	0.990822285	;
scalar d6m08	=	1	;
scalar d6m09	=	1.007629278	;
scalar d6m10	=	1.014032711	;
scalar d6m11	=	1.019274815	;

*Rubro 6 semestral, Transporte;

scalar d6s02	=	0.979756067	;
scalar d6s03	=	0.985035808	;
scalar d6s04	=	0.990415013	;
scalar d6s05	=	0.996299612	;

*Rubro 7 mensual, Educacin y esparcimiento;

scalar d7m07	=	0.996539589	;
scalar d7m08	=	1	;
scalar d7m09	=	1.018093842	;
scalar d7m10	=	1.020146628	;
scalar d7m11	=	1.023013196	;

*Rubro 2.3 mensual, Accesorios y cuidados del vestido;

scalar d23m07	=	1.008233945	;
scalar d23m08	=	1	;
scalar d23m09	=	0.998860856	;
scalar d23m10	=	1.007889908	;
scalar d23m11	=	1.012568807	;

*Rubro 2.3 trimestral,  Accesorios y cuidados del vestido;

scalar d23t05	=	1.004801223	;
scalar d23t06	=	1.00401631	;
scalar d23t07	=	1.002364934	;
scalar d23t08	=	1.002250255	;

*INPC semestral;

scalar dINPCs02	=	0.985556739	;
scalar dINPCs03	=	0.989486222	;
scalar dINPCs04	=	0.993371972	;
scalar dINPCs05	=	0.998028184	;

*Una vez definidos los deflactores, se seleccionan los 
rubros;

gen double gasnomon=apo_tri/3;

gen esp=1 if tipogasto==2;
gen reg=1 if tipogasto==3;
replace reg=1 if tipogasto==4;
drop if tipogasto==1 ;

*Control para la frecuencia de los regalos recibidos, para no monetario ENIGH;

drop if ((frecu>=5 & frecu<=6) | frecu==.) & proyecto=="2" & tipogasto==3;

*Para no monetario MCS;

drop if ((frecu>=11 & frecu<=12) | frecu==.) & proyecto=="1" & tipogasto==3;

*Gasto en Alimentos deflactado (semanal) ;

gen ali_nm=gasnomon if (clave>="A001" & clave<="A222") | 
(clave>="A242" & clave<="A247");

replace ali_nm=ali_nm/d11w08 if decena==0;
replace ali_nm=ali_nm/d11w08 if decena==1;
replace ali_nm=ali_nm/d11w08 if decena==2;
replace ali_nm=ali_nm/d11w09 if decena==3;
replace ali_nm=ali_nm/d11w09 if decena==4;
replace ali_nm=ali_nm/d11w09 if decena==5;
replace ali_nm=ali_nm/d11w10 if decena==6;
replace ali_nm=ali_nm/d11w10 if decena==7;
replace ali_nm=ali_nm/d11w10 if decena==8;
replace ali_nm=ali_nm/d11w11 if decena==9;

*Gasto en Alcohol y tabaco deflactado (semanal);

gen alta_nm=gasnomon if (clave>="A223" & clave<="A241");

replace alta_nm=alta_nm/d12w08 if decena==0;
replace alta_nm=alta_nm/d12w08 if decena==1;
replace alta_nm=alta_nm/d12w08 if decena==2;
replace alta_nm=alta_nm/d12w09 if decena==3;
replace alta_nm=alta_nm/d12w09 if decena==4;
replace alta_nm=alta_nm/d12w09 if decena==5;
replace alta_nm=alta_nm/d12w10 if decena==6;
replace alta_nm=alta_nm/d12w10 if decena==7;
replace alta_nm=alta_nm/d12w10 if decena==8;
replace alta_nm=alta_nm/d12w11 if decena==9;

*Gasto en Vestido y calzado deflactado (trimestral);

gen veca_nm=gasnomon if (clave>="H001" & clave<="H122") | 
(clave=="H136");

replace veca_nm=veca_nm/d2t05 if decena==0;
replace veca_nm=veca_nm/d2t05 if decena==1;
replace veca_nm=veca_nm/d2t06 if decena==2;
replace veca_nm=veca_nm/d2t06 if decena==3;
replace veca_nm=veca_nm/d2t06 if decena==4;
replace veca_nm=veca_nm/d2t07 if decena==5;
replace veca_nm=veca_nm/d2t07 if decena==6;
replace veca_nm=veca_nm/d2t07 if decena==7;
replace veca_nm=veca_nm/d2t08 if decena==8;
replace veca_nm=veca_nm/d2t08 if decena==9;

*Gasto en Vivienda y servicios de conservacin deflactado (mensual);

gen viv_nm=gasnomon if (clave>="G001" & clave<="G022");

replace viv_nm=viv_nm/d3m07 if decena==0;
replace viv_nm=viv_nm/d3m07 if decena==1;
replace viv_nm=viv_nm/d3m08 if decena==2;
replace viv_nm=viv_nm/d3m08 if decena==3;
replace viv_nm=viv_nm/d3m08 if decena==4;
replace viv_nm=viv_nm/d3m09 if decena==5;
replace viv_nm=viv_nm/d3m09 if decena==6;
replace viv_nm=viv_nm/d3m09 if decena==7;
replace viv_nm=viv_nm/d3m10 if decena==8;
replace viv_nm=viv_nm/d3m10 if decena==9;

*Gasto en Artculos de limpieza deflactado (mensual);

gen lim_nm=gasnomon if (clave>="C001" & clave<="C024");

replace lim_nm=lim_nm/d42m07 if decena==0;
replace lim_nm=lim_nm/d42m07 if decena==1;
replace lim_nm=lim_nm/d42m08 if decena==2;
replace lim_nm=lim_nm/d42m08 if decena==3;
replace lim_nm=lim_nm/d42m08 if decena==4;
replace lim_nm=lim_nm/d42m09 if decena==5;
replace lim_nm=lim_nm/d42m09 if decena==6;
replace lim_nm=lim_nm/d42m09 if decena==7;
replace lim_nm=lim_nm/d42m10 if decena==8;
replace lim_nm=lim_nm/d42m10 if decena==9;

*Gasto en Cristalera y blancos deflactado (trimestral);

gen cris_nm=gasnomon if (clave>="I001" & clave<="I026");

replace cris_nm=cris_nm/d42t05 if decena==0;
replace cris_nm=cris_nm/d42t05 if decena==1;
replace cris_nm=cris_nm/d42t06 if decena==2;
replace cris_nm=cris_nm/d42t06 if decena==3;
replace cris_nm=cris_nm/d42t06 if decena==4;
replace cris_nm=cris_nm/d42t07 if decena==5;
replace cris_nm=cris_nm/d42t07 if decena==6;
replace cris_nm=cris_nm/d42t07 if decena==7;
replace cris_nm=cris_nm/d42t08 if decena==8;
replace cris_nm=cris_nm/d42t08 if decena==9;

*Gasto en Enseres domsticos y muebles deflactado (semestral);

gen ens_nm=gasnomon if (clave>="K001" & clave<="K036");

replace ens_nm=ens_nm/d41s02 if decena==0;
replace ens_nm=ens_nm/d41s02 if decena==1;
replace ens_nm=ens_nm/d41s03 if decena==2;
replace ens_nm=ens_nm/d41s03 if decena==3;
replace ens_nm=ens_nm/d41s03 if decena==4;
replace ens_nm=ens_nm/d41s04 if decena==5;
replace ens_nm=ens_nm/d41s04 if decena==6;
replace ens_nm=ens_nm/d41s04 if decena==7;
replace ens_nm=ens_nm/d41s05 if decena==8;
replace ens_nm=ens_nm/d41s05 if decena==9;

*Gasto en Salud deflactado (trimestral);

gen sal_nm=gasnomon if (clave>="J001" & clave<="J072");

replace sal_nm=sal_nm/d51t05 if decena==0;
replace sal_nm=sal_nm/d51t05 if decena==1;
replace sal_nm=sal_nm/d51t06 if decena==2;
replace sal_nm=sal_nm/d51t06 if decena==3;
replace sal_nm=sal_nm/d51t06 if decena==4;
replace sal_nm=sal_nm/d51t07 if decena==5;
replace sal_nm=sal_nm/d51t07 if decena==6;
replace sal_nm=sal_nm/d51t07 if decena==7;
replace sal_nm=sal_nm/d51t08 if decena==8;
replace sal_nm=sal_nm/d51t08 if decena==9;

*Gasto en Transporte pblico deflactado (semanal);

gen tpub_nm=gasnomon if (clave>="B001" & clave<="B007");

replace tpub_nm=tpub_nm/d611w08 if decena==0;
replace tpub_nm=tpub_nm/d611w08 if decena==1;
replace tpub_nm=tpub_nm/d611w08 if decena==2;
replace tpub_nm=tpub_nm/d611w09 if decena==3;
replace tpub_nm=tpub_nm/d611w09 if decena==4;
replace tpub_nm=tpub_nm/d611w09 if decena==5;
replace tpub_nm=tpub_nm/d611w10 if decena==6;
replace tpub_nm=tpub_nm/d611w10 if decena==7;
replace tpub_nm=tpub_nm/d611w10 if decena==8;
replace tpub_nm=tpub_nm/d611w11 if decena==9;

*Gasto en Transporte forneo deflactado (semestral);

gen tfor_nm=gasnomon if (clave>="M001" & clave<="M018") | 
(clave>="F010" & clave<="F017");

replace tfor_nm=tfor_nm/d6s02 if decena==0;
replace tfor_nm=tfor_nm/d6s02 if decena==1;
replace tfor_nm=tfor_nm/d6s03 if decena==2;
replace tfor_nm=tfor_nm/d6s03 if decena==3;
replace tfor_nm=tfor_nm/d6s03 if decena==4;
replace tfor_nm=tfor_nm/d6s04 if decena==5;
replace tfor_nm=tfor_nm/d6s04 if decena==6;
replace tfor_nm=tfor_nm/d6s04 if decena==7;
replace tfor_nm=tfor_nm/d6s05 if decena==8;
replace tfor_nm=tfor_nm/d6s05 if decena==9;

*Gasto en Comunicaciones deflactado (mensual);

gen com_nm=gasnomon if (clave>="F001" & clave<="F009");

replace com_nm=com_nm/d6m07 if decena==0;
replace com_nm=com_nm/d6m07 if decena==1;
replace com_nm=com_nm/d6m08 if decena==2;
replace com_nm=com_nm/d6m08 if decena==3;
replace com_nm=com_nm/d6m08 if decena==4;
replace com_nm=com_nm/d6m09 if decena==5;
replace com_nm=com_nm/d6m09 if decena==6;
replace com_nm=com_nm/d6m09 if decena==7;
replace com_nm=com_nm/d6m10 if decena==8;
replace com_nm=com_nm/d6m10 if decena==9;

*Gasto en Educacin y recreacin deflactado (mensual);

gen edre_nm=gasnomon if (clave>="E001" & clave<="E033") | 
(clave>="H134" & clave<="H135") | (clave>="L001" & 
clave<="L029") | (clave>="N003" & clave<="N005");

replace edre_nm=edre_nm/d7m07 if decena==0;
replace edre_nm=edre_nm/d7m07 if decena==1;
replace edre_nm=edre_nm/d7m08 if decena==2;
replace edre_nm=edre_nm/d7m08 if decena==3;
replace edre_nm=edre_nm/d7m08 if decena==4;
replace edre_nm=edre_nm/d7m09 if decena==5;
replace edre_nm=edre_nm/d7m09 if decena==6;
replace edre_nm=edre_nm/d7m09 if decena==7;
replace edre_nm=edre_nm/d7m10 if decena==8;
replace edre_nm=edre_nm/d7m10 if decena==9;

*Gasto en Educacin bsica deflactado (mensual);

gen edba_nm=gasnomon if (clave>="E002" & clave<="E003") | 
(clave>="H134" & clave<="H135");

replace edba_nm=edba_nm/d7m07 if decena==0;
replace edba_nm=edba_nm/d7m07 if decena==1;
replace edba_nm=edba_nm/d7m08 if decena==2;
replace edba_nm=edba_nm/d7m08 if decena==3;
replace edba_nm=edba_nm/d7m08 if decena==4;
replace edba_nm=edba_nm/d7m09 if decena==5;
replace edba_nm=edba_nm/d7m09 if decena==6;
replace edba_nm=edba_nm/d7m09 if decena==7;
replace edba_nm=edba_nm/d7m10 if decena==8;
replace edba_nm=edba_nm/d7m10 if decena==9;

*Gasto en Cuidado personal deflactado (mensual);

gen cuip_nm=gasnomon if (clave>="D001" & clave<="D026") | 
(clave=="H132");

replace cuip_nm=cuip_nm/d23m07 if decena==0;
replace cuip_nm=cuip_nm/d23m07 if decena==1;
replace cuip_nm=cuip_nm/d23m08 if decena==2;
replace cuip_nm=cuip_nm/d23m08 if decena==3;
replace cuip_nm=cuip_nm/d23m08 if decena==4;
replace cuip_nm=cuip_nm/d23m09 if decena==5;
replace cuip_nm=cuip_nm/d23m09 if decena==6;
replace cuip_nm=cuip_nm/d23m09 if decena==7;
replace cuip_nm=cuip_nm/d23m10 if decena==8;
replace cuip_nm=cuip_nm/d23m10 if decena==9;

*Gasto en Accesorios personales deflactado (trimestral);

gen accp_nm=gasnomon if (clave>="H123" & clave<="H131") | 
(clave=="H133");

replace accp_nm=accp_nm/d23t05 if decena==0;
replace accp_nm=accp_nm/d23t05 if decena==1;
replace accp_nm=accp_nm/d23t06 if decena==2;
replace accp_nm=accp_nm/d23t06 if decena==3;
replace accp_nm=accp_nm/d23t06 if decena==4;
replace accp_nm=accp_nm/d23t07 if decena==5;
replace accp_nm=accp_nm/d23t07 if decena==6;
replace accp_nm=accp_nm/d23t07 if decena==7;
replace accp_nm=accp_nm/d23t08 if decena==8;
replace accp_nm=accp_nm/d23t08 if decena==9;

*Gasto en Otros gastos y transferencias deflactado (semestral);

gen otr_nm=gasnomon if (clave>="N001" & clave<="N002") | 
(clave>="N006" & clave<="N016") | (clave>="T901" & 
clave<="T914");

replace otr_nm=otr_nm/dINPCs02 if decena==0;
replace otr_nm=otr_nm/dINPCs02 if decena==1;
replace otr_nm=otr_nm/dINPCs03 if decena==2;
replace otr_nm=otr_nm/dINPCs03 if decena==3;
replace otr_nm=otr_nm/dINPCs03 if decena==4;
replace otr_nm=otr_nm/dINPCs04 if decena==5;
replace otr_nm=otr_nm/dINPCs04 if decena==6;
replace otr_nm=otr_nm/dINPCs04 if decena==7;
replace otr_nm=otr_nm/dINPCs05 if decena==8;
replace otr_nm=otr_nm/dINPCs05 if decena==9;

*Gasto en Regalos Otorgados deflactado;

gen reda_nm=gasnomon if (clave>="T901" & clave<="T914") | (clave=="N013");

replace reda_nm=reda_nm/dINPCs02 if decena==1;
replace reda_nm=reda_nm/dINPCs03 if decena==2;
replace reda_nm=reda_nm/dINPCs03 if decena==3;
replace reda_nm=reda_nm/dINPCs03 if decena==4;
replace reda_nm=reda_nm/dINPCs04 if decena==5;
replace reda_nm=reda_nm/dINPCs04 if decena==6;
replace reda_nm=reda_nm/dINPCs04 if decena==7;
replace reda_nm=reda_nm/dINPCs05 if decena==8;
replace reda_nm=reda_nm/dINPCs05 if decena==9;

save "$bases\ingresonomonetario_def08.dta", replace;

use "$bases\ingresonomonetario_def08.dta", clear;

*Construccin de la base de pagos en especie a partir de la base 
de gasto no monetario;

keep if esp==1;

collapse (sum) *_nm, by(proyecto folioviv foliohog);

rename  ali_nm ali_nme;
rename  alta_nm alta_nme;
rename  veca_nm veca_nme;
rename  viv_nm viv_nme;
rename  lim_nm lim_nme;
rename  cris_nm cris_nme;
rename  ens_nm ens_nme;
rename  sal_nm sal_nme;
rename  tpub_nm tpub_nme;
rename  tfor_nm tfor_nme;
rename  com_nm com_nme; 
rename  edre_nm edre_nme;
rename  edba_nm edba_nme;
rename  cuip_nm cuip_nme;
rename  accp_nm accp_nme;
rename  otr_nm otr_nme;
rename  reda_nm reda_nme;

sort proyecto folioviv foliohog;

save "$bases\esp_def08.dta", replace;

use "$bases\ingresonomonetario_def08.dta", clear;

*Construccin de base de regalos a partir de la base no 
monetaria ;

keep if reg==1;

collapse (sum) *_nm, by(proyecto folioviv foliohog);

rename  ali_nm ali_nmr;
rename  alta_nm alta_nmr;
rename  veca_nm veca_nmr;
rename  viv_nm viv_nmr;
rename  lim_nm lim_nmr;
rename  cris_nm cris_nmr;
rename  ens_nm ens_nmr;
rename  sal_nm sal_nmr;
rename  tpub_nm tpub_nmr;
rename  tfor_nm tfor_nmr;
rename  com_nm com_nmr; 
rename  edre_nm edre_nmr;
rename  edba_nm edba_nmr;
rename  cuip_nm cuip_nmr;
rename  accp_nm accp_nmr;
rename  otr_nm otr_nmr;
rename  reda_nm reda_nmr;

sort proyecto folioviv foliohog;

save "$bases\reg_def08.dta", replace;

*********************************************************

Construccin del ingreso corriente total

*********************************************************;

use "$data\concentrado08.dta", clear;

keep proyecto folioviv foliohog estrato factor tam_hog est_dis upm;

*Incorporacin de la base de ingreso monetario deflactado;

sort proyecto folioviv foliohog;

merge proyecto folioviv foliohog using "$bases\ingreso_deflactado08.dta";
tab _merge;
drop _merge;

*Incorporacin de la base de ingreso no monetario deflactado: pago en especie;

sort proyecto folioviv foliohog;

merge proyecto folioviv foliohog using "$bases\esp_def08.dta";
tab _merge;
drop _merge;

*Incorporacin de la base de ingreso no monetario deflactado: regalos en especie;

sort proyecto folioviv foliohog;

merge proyecto folioviv foliohog using "$bases\reg_def08.dta";
tab _merge;
drop _merge;

gen rururb=1 if estrato==4;
replace rururb=0 if estrato<=3;
label define rururb 1 "Rural" 
                    0 "Urbano";
label value rururb rururb;

egen double pago_esp=rsum(ali_nme alta_nme veca_nme 
viv_nme lim_nme ens_nme cris_nme sal_nme 
tpub_nme tfor_nme com_nme edre_nme cuip_nme 
accp_nme otr_nme);

egen double reg_esp=rsum(ali_nmr alta_nmr veca_nmr 
viv_nmr lim_nmr ens_nmr cris_nmr sal_nmr 
tpub_nmr tfor_nmr com_nmr edre_nmr cuip_nmr 
accp_nmr otr_nmr);

egen double nomon=rsum(pago_esp reg_esp);

egen double ict=rsum(ing_mon nomon);

label var ict "Ingreso corriente total";

sort proyecto folioviv foliohog;

save "$bases\ingresotot08.dta", replace;

***********************************************************

Construccin del tamao de hogar con economas de escala
y escalas de equivalencia

***********************************************************;

use "$data\poblacion08.dta", clear;

drop if ((parentesco>=400 & parentesco<500) | parentesco>=700);

*Total de integrantes del hogar;

gen ind=1;
egen tot_ind=sum(ind), by (proyecto folioviv foliohog);

*************************
*Escalas de equivalencia*
*************************;

*Poblacin objeto;

drop if parentesco>=400 & parentesco <500;
drop if parentesco>=700 & parentesco <800;
gen n_05=.;
replace n_05=1 if edad>=0 & edad<=5;
recode n_05 (.=0) if edad!=.;

gen n_6_12=0;
replace n_6_12=1 if edad>=6 & edad<=12;
recode n_6_12 (.=0) if edad!=.;

gen n_13_18=0;
replace n_13_18=1 if edad>=13 & edad<=18;
recode n_13_18 (.=0) if edad!=.;

gen n_19=0;
replace n_19=1 if edad>=19 & edad!=.;
recode n_05 (.=0) if edad!=.;

gen tamhogesc=n_05*.7031;
replace tamhogesc=n_6_12*.7382 if n_6_12==1;
replace tamhogesc=n_13_18*.7057 if n_13_18==1;
replace tamhogesc=n_19*.9945 if n_19==1 ;
replace tamhogesc=1 if tot_ind==1;

collapse (sum) tamhogesc, by(proyecto folioviv foliohog);

sort proyecto folioviv foliohog;

save "$bases\tamhogesc08.dta", replace;

*******************************************************

Bienestar por ingresos

*******************************************************;

use "$bases\ingresotot08.dta", clear;

*Incorporacin de la informacin sobre el tamao del hogar ajustado;

merge proyecto folioviv foliohog using "$bases\tamhogesc08.dta";
tab _merge;
drop _merge;

*Informacin per capita;

gen double ictpc= ict/tamhogesc;

label var  ictpc "Ingreso corriente total per capita";

*Generacin del factor de expansin para personas;

gen factorp=factor*tam_hog;

**********************************************

Indicador de Bienestar por ingresos

**********************************************

LP I: Valor de la Canasta para bienestar mnimo 

LP II: Valor de la Canasta Alimentaria ms el valor de la canasta
no alimentaria (ver Anexo A del documento metodolgico).

En este programa se construyen los indicadores de bienestar por ingresos
mediante las 2 lneas definidas por CONEVAL , denominndoles:

lp1 : Lnea de Bienestar Mnimo
lp2 : Lnea de Bienestar

**********************************************;


**********************************************

Bienestar mnimo

**********************************************;

*Valor de la canasta bsica (ver Nota Tcnica);

scalar lp1_urb = 874.63;
scalar lp1_rur = 613.80;

*Se identifica a los hogares bajo LP1;

gen  plb_m=1 if ictpc<=lp1_urb & rururb==0;
replace plb_m=0 if ictpc>lp1_urb & rururb==0 & ictpc!=.;
replace plb_m=1 if ictpc<=lp1_rur & rururb==1;
replace plb_m=0 if ictpc>lp1_rur & rururb==1 & ictpc!=.;

**********************************************

Bienestar

**********************************************;

scalar lp2_urb = 1921.74;
scalar lp2_rur = 1202.80;

gen  plb=1 if (ictpc<=lp2_urb & rururb==0);
replace plb=0 if (ictpc>lp2_urb & rururb==0) & ictpc!=.;

replace plb=1 if (ictpc<=lp2_rur & rururb==1);
replace plb=0 if (ictpc>lp2_rur & rururb==1) & ictpc!=.;

label var factor "Factor de expansin a nivel hogar";
label var factorp "Factor de expansin para personas";
label var estrato "Tamao de la localidad";
label var rururb "Identificador de localidades rurales";
label var tam_hog "Total de integrantes del hogar";
label var tamhogesc "Tamao de hogar ajustado";
label var ict "Ingreso corriente total del hogar";
label var ictpc "Ingreso corriente total per cpita";
label var plb_m "Identificador de los hogares con ingreso inferior a la lnea de bienestar mnimo";
label var plb "Identificador de los hogares con ingreso inferior a la lnea de bienestar
";

keep proyecto folioviv foliohog factor estrato 
rururb tamhogesc ict ictpc plb_m plb est_dis upm;

sort proyecto folioviv foliohog;

save "$bases\p_ingresos08.dta", replace;

*********************************************************

Parte VIII Pobreza Multidimensional

*********************************************************;

**************************
Integracin de las bases*
*************************;

use "$bases\ic_rezedu08.dta", clear;

merge proyecto folioviv foliohog numren using "$bases\ic_asalud08.dta";

tab _merge;
drop _merge;

sort proyecto folioviv foliohog numren;

merge proyecto folioviv foliohog numren using "$bases\ic_segsoc08.dta";

tab _merge;
drop _merge;

sort proyecto folioviv foliohog;

merge proyecto folioviv foliohog using "$bases\ic_cev08.dta";

tab _merge;
drop _merge;

sort proyecto folioviv foliohog;

merge proyecto folioviv foliohog using "$bases\ic_sbv08.dta";

tab _merge;
drop _merge;

sort proyecto folioviv foliohog;

merge proyecto folioviv foliohog using "$bases\ic_ali08.dta";

tab _merge;
drop _merge;

sort proyecto folioviv foliohog;

merge proyecto folioviv foliohog using "$bases\p_ingresos08.dta";

tab _merge;
drop _merge;

duplicates drop proyecto folioviv foliohog numren, force;

gen ent=real(substr(folioviv,1,2));

label var ent "Identificador de la entidad federativa";

label define ent 
1	"Aguascalientes"
2	"Baja California"
3	"Baja California Sur"
4	"Campeche"
5	"Coahuila"
6	"Colima"
7	"Chiapas"
8	"Chihuahua"
9	"Distrito Federal"
10	"Durango"
11	"Guanajuato"
12	"Guerrero"
13	"Hidalgo"
14	"Jalisco"
15	"Mxico"
16	"Michoacn"
17	"Morelos"
18	"Nayarit"
19	"Nuevo Len"
20	"Oaxaca"
21	"Puebla"
22	"Quertaro"
23	"Quintana Roo"
24	"San Luis Potos"
25	"Sinaloa"
26	"Sonora"
27	"Tabasco"
28	"Tamaulipas"
29	"Tlaxcala"
30	"Veracruz"
31	"Yucatn"
32	"Zacatecas";
label value ent ent;

****************************
*ndice de Privacin Social*
****************************;

*Este ndice se construye para cada persona a partir de la suma 
de los seis indicadores asociados a las carencias sociales;

egen i_privacion=rsum(ic_rezedu ic_asalud ic_segsoc ic_cv ic_sbv ic_ali);
replace i_privacion=. if ic_rezedu==. | ic_asalud==. | ic_segsoc==. | 
ic_cv==. | ic_sbv==. | ic_ali==.;

label var i_privacion "ndice de Privacin Social";

***************************
*Pobreza multidimensional*
***************************;

*Una persona se encuentra en situacin de pobreza multidimensional 
cuando presenta al menos una carencia social y su ingreso es
inferior a la lnea de bienestar;

gen p_multi=1 if plb==1 & (i_privacion>=1 & i_privacion!=.);
replace p_multi=0 if (plb==0 | i_privacion==0) & (plb!=. & i_privacion!=.);

label var p_multi "Pobreza multidimensional";
label define p_multi 0 "No pobre multidimensional" 
                     1 "Pobreza multidimensional";
label value p_multi p_multi;

*Una persona se encuentra en situacin de pobreza multidimensional extrema
cuando presenta al menos tres carencias sociales y su ingreso es inferior 
a la lnea de bienestar mnimo;

gen pe_multi=1 if plb_m==1 & (i_privacion>=3 & i_privacion!=.);
replace pe_multi=0 if (plb_m==0 | i_privacion<3) & (plb_m!=. & i_privacion!=.);

label var pe_multi "Pobreza multidimensional extrema";
label define pe_multi 0 "No pobre multidimensional extremo" 
                      1 "Pobreza multidimensional extrema";
label value pe_multi pe_multi;

*Una persona se encuentra en situacin de pobreza multidimensional moderada
cuando presenta menos de tres carencias sociales, y su ingreso es superior a la 
lnea de bienestar mnimo, pero inferior a la lnea de bienestar;

gen pm_multi=1 if p_multi==1 & pe_multi==0;
replace pm_multi=0 if p_multi==0 | (p_multi==1 & pe_multi==1);

label var pm_multi "Pobreza multidimensional moderada";
label define pm_multi 0 "No pobre multidimensional moderado " 
                      1 "Pobreza multidimensional moderada";
label value pm_multi pm_multi;

*******************************
*Poblacin vulnerable
*******************************;

*Existen dos grupos de poblacin vulnerable:

Vulnerables por carencias sociales.- Poblacin que presenta una o ms carencias sociales y 
 cuyo ingreso es superior a la lnea de bienestar;

gen vul_car=cond(plb==0 & (i_privacion>=1 & i_privacion!=.),1,0);
replace vul_car=. if p_multi==.;

label var vul_car "Poblacin vulnerable por carencias";
label define vul_car 0 "No vulnerable" 
                     1 "Vulnerable";
label value vul_car vul_car;

*Vulnerables por ingresos.- Poblacin que no presenta carencias sociales y cuyo ingreso 
es inferior o igual a la lnea de bienestar;

gen vul_ing=cond(plb==1 & i_privacion==0,1,0);
replace vul_ing=. if p_multi==.;

label var vul_ing "Poblacin vulnerable por ingresos";
label define vul_ing 0 "No vulnerable" 
                     1 "Vulnerable";
label value vul_ing vul_ing;

************************************
*Poblacin no pobre multidimensional 
*y no vulnerable
************************************;

* Se considera poblacin no pobre multidimensional y no vulnerable aquella cuyo 
ingreso es superior a la lnea de bienestar y que no tiene carencia social alguna;

gen pnpmnv=cond(plb==0 & i_privacion==0,1,0);
replace pnpmnv=. if p_multi==.;

label var pnpmnv "Poblacin no pobre multidimensional y no vulnerable";
label define pnpmnv     0 "Pobre multidimensional o vulnerable" 
				1 "No pobre multidimensional y no vulnerable";
label value pnpmnv pnpmnv;

************************
*Poblacin carenciada 
************************;

* Se considera poblacin carenciada aquella que presenta al menos una carencia social;

gen carenciada=cond(i_privacion>0 & i_privacio!=.,1,0);
replace carenciada=. if p_multi==.;

label var carenciada "Poblacin con al menos una carencia";
label define carenciada 0 "Poblacin sin carencias" 
		            1 "Poblacin carenciada";
label value carenciada carenciada;

************
*Cuadrantes*
************;

*A partir de la lnea de bienestar y el umbral de privacin, es posible categorizar 
a la poblacin en cuatro grupos o cuadrantes:

1. Poblacin pobre multidimensional
2. Poblacin vulnerable por carencias
3. Poblacin vulnerable por ingresos
4. Poblacin no pobre multidimensional y no vulnerable;

gen cuadrantes=.;
replace cuadrantes=1 if plb==1 & (i_privacion>=1 & i_privacion!=.);
replace cuadrantes=2 if plb==0 & (i_privacion>=1 & i_privacion!=.);
replace cuadrantes=3 if plb==1 & i_privacion==0;
replace cuadrantes=4 if plb==0 & i_privacion==0;

label var cuadrantes "Cuadrantes de Bienestar y Derechos sociales";
label define cuadrantes       1 "Pobres multidimensionales"
					2 "Vulnerables por carencias" 
					3 "Vulnerables por ingresos"
					4 "No pobres multidimensionales y no vulnerables";
label value cuadrantes cuadrantes;

*****************************************
*Profundidad en el espacio del bienestar*
*****************************************;

**********
FGT (a=1)*
**********;

*Distancia normalizada del ingreso respecto a la lnea de bienestar;

gen prof_b1=(lp2_rur-ictpc)/(lp2_rur) if rururb==1 & plb==1;
replace prof_b1=(lp2_urb-ictpc)/(lp2_urb) if rururb==0 & plb==1;
recode prof_b1 (.=0) if ictpc!=.;

label var prof_b1 "ndice FGT con alfa igual a 1 (lnea de bienestar)";

*Distancia normalizada del ingreso respecto a la lnea de bienestar mnimo;

gen prof_bm1=(lp1_rur-ictpc)/(lp1_rur) if rururb==1 & plb_m==1;
replace prof_bm1=(lp1_urb-ictpc)/(lp1_urb) if rururb==0 & plb_m==1;
recode prof_bm1 (.=0) if ictpc!=.;

label var prof_bm1 "ndice FGT con alfa igual a 1 (lnea de bienestar mnimo)";

************************************
*Profundidad de la privacin social*
************************************;

gen profun=i_privacion/6;

label var profun "Profundidad de la privacin social";

***********************************
*Intensidad de la privacin social*
***********************************;

*Poblacin pobre multidimensional;

gen int_multi=profun*p_multi;

label var int_multi "Intensidad de la privacin social: pobres multidimensionales";

*Poblacin pobre multidimensional extrema;

gen int_multie=profun*pe_multi;

label var int_multie "Intensidad de la privacin social: pobres multidimensionales extremos";

*Poblacin vulnerable por carencias;

gen int_vulcar=profun*vul_car;

label var int_vulcar "Intensidad de la privacin social: poblacin vulnerable por carencias";

*Poblacin carenciada;

gen int_caren=profun*carenciada;

label var int_caren "Intensidad de la privacin social: poblacin carenciada";

keep 	proyecto folioviv foliohog numren factor estrato rururb ent edad sexo 
		ic_rezedu ic_asalud ic_segsoc ic_cv ic_sbv ic_ali 
		ictpc plb_m plb est_dis upm
		i_privacion p_multi pe_multi pm_multi  vul_car vul_ing pnpmnv carenciada cuadrantes 
		prof_b1 prof_bm1 profun int_multi int_multie int_vulcar int_caren;

order 	proyecto folioviv foliohog numren factor estrato rururb ent edad sexo 
		ic_rezedu ic_asalud ic_segsoc ic_cv ic_sbv ic_ali 
		ictpc plb_m plb est_dis upm
		i_privacion p_multi pe_multi pm_multi  vul_car vul_ing pnpmnv carenciada cuadrantes 
		prof_b1 prof_bm1 profun int_multi int_multie int_vulcar int_caren;

sort proyecto folioviv foliohog numren;

save "$bases\pobreza_multidimensional08.dta", replace;

*******************************
*
*	Concentrado estadstico
*	Nacional
*
*******************************;

*Debido a la existencia de observaciones con valores faltantes, es necesario restringir los resultados 
a la poblacin de la que se dispone de la informacin completa. Esta restriccin se incorpora en todos
los tabulados mediante la instruccin "if p_multi!=.";

**************************************
*Incidencia de las carencias sociales*
**************************************;
sort proyecto folioviv foliohog numren;

tabstat ic_rezedu ic_asalud ic_segsoc ic_cv ic_sbv ic_ali [fw=factor] if p_multi!=., stats(mean) by(ent) format(%12.4gc);

**************************************************
*Poblacin con cada una de las carencias sociales*
**************************************************;

tabstat ic_rezedu ic_asalud ic_segsoc ic_cv ic_sbv ic_ali [fw=factor] if p_multi!=., stats(sum) by(ent) format(%12.0gc);

*******************************************************
*Incidencia en cada espacio y pobreza multidimensional*
*******************************************************;

tabstat plb plb_m carenciada p_multi pe_multi pm_multi [fw=factor] if p_multi!=., stats(mean) by(ent) format(%12.4gc);

******************************************************
*Poblacin en cada espacio y pobreza multidimensional*
******************************************************;

tabstat plb plb_m carenciada p_multi pe_multi pm_multi [fw=factor] if p_multi!=., stats(sum) by(ent) format(%12.0gc);

************
*Cuadrantes*
************;

tab ent cuadrantes [fw=factor];

tab ent cuadrantes [fw=factor], nofreq row;

*****************************************
*Profundidad en el espacio del bienestar*
*****************************************;

tabstat prof_b1 prof_bm1 [fw=factor] if carenciada==1 & p_multi!=., by(ent) stats(mean);

tabstat prof_b1 prof_bm1 [fw=factor] if carenciada==0 & p_multi!=., by(ent) stats(mean);

*****************************
*Profundidad de la privacin*
*****************************;

*Pobres multidimensionales;

tabstat i_privacion profun [fw=factor] if p_multi==1, by(ent) stats(mean);

*Pobres multidimensionales extremos;

tabstat i_privacion profun [fw=factor] if pe_multi==1, by(ent) stats(mean);

*Pobres vulnerable por carencias;

tabstat i_privacion profun [fw=factor] if vul_car==1, by(ent) stats(mean);

*Poblacin carenciada;

tabstat i_privacion profun [fw=factor] if carenciada==1, by(ent) stats(mean);

sort proyecto folioviv foliohog numren;

****************************
*Intensidad de la privacin*
****************************;

tabstat int_multi int_multie int_vulcar int_caren [fw=factor], by(ent) stats(mean);

log close;

